"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .accruing_time_off_hour import AccruingTimeOffHour, AccruingTimeOffHourTypedDict
from .ach_transaction import (
    AchTransaction,
    AchTransactionRecipientType,
    AchTransactionTypedDict,
    PaymentDirection,
    PaymentEventType,
    PaymentStatus,
)
from .admin import Admin, AdminTypedDict
from .apierror import APIError
from .authentication import Authentication, AuthenticationTypedDict
from .benefit_summary import (
    BenefitSummary,
    BenefitSummaryEmployees,
    BenefitSummaryEmployeesTypedDict,
    BenefitSummaryPayPeriod,
    BenefitSummaryPayPeriodTypedDict,
    BenefitSummaryTypedDict,
    PayrollBenefits,
    PayrollBenefitsTypedDict,
)
from .benefit_type_requirements import (
    BenefitTypeRequirements,
    BenefitTypeRequirementsCatchUpDefaultValue,
    BenefitTypeRequirementsCatchUpDefaultValueTypedDict,
    BenefitTypeRequirementsCompanyContributionAnnualMaximumDefaultValue,
    BenefitTypeRequirementsCompanyContributionAnnualMaximumDefaultValueTypedDict,
    BenefitTypeRequirementsContribution,
    BenefitTypeRequirementsContributionTypedDict,
    BenefitTypeRequirementsCoverageAmountDefaultValue,
    BenefitTypeRequirementsCoverageAmountDefaultValueTypedDict,
    BenefitTypeRequirementsCoverageSalaryMultiplierDefaultValue,
    BenefitTypeRequirementsCoverageSalaryMultiplierDefaultValueTypedDict,
    BenefitTypeRequirementsDeductAsPercentageDefaultValue,
    BenefitTypeRequirementsDeductAsPercentageDefaultValueTypedDict,
    BenefitTypeRequirementsDefaultValue,
    BenefitTypeRequirementsDefaultValueTypedDict,
    BenefitTypeRequirementsLimitOptionDefaultValue,
    BenefitTypeRequirementsLimitOptionDefaultValueTypedDict,
    BenefitTypeRequirementsTypedDict,
    CatchUp,
    CatchUpTypedDict,
    CompanyContributionAnnualMaximum,
    CompanyContributionAnnualMaximumTypedDict,
    CoverageAmount,
    CoverageAmountTypedDict,
    CoverageSalaryMultiplier,
    CoverageSalaryMultiplierTypedDict,
    DeductAsPercentage,
    DeductAsPercentageTypedDict,
    DefaultValue,
    DefaultValueTypedDict,
    EmployeeDeduction,
    EmployeeDeductionTypedDict,
    LimitOption,
    LimitOptionTypedDict,
)
from .child_support_data import (
    Agencies,
    AgenciesTypedDict,
    ChildSupportData,
    ChildSupportDataTypedDict,
    FipsCodes,
    FipsCodesTypedDict,
    Key,
    RequiredAttributes,
    RequiredAttributesTypedDict,
)
from .company import (
    Company,
    CompanyHomeAddress,
    CompanyHomeAddressTypedDict,
    CompanyPaidTimeOff,
    CompanyPaidTimeOffTypedDict,
    CompanyStatus,
    CompanyTypedDict,
    Compensations,
    CompensationsTypedDict,
    EntityType,
    Fixed,
    FixedTypedDict,
    FundingType,
    Hourly,
    HourlyTypedDict,
    PayScheduleType,
    PrimaryPayrollAdmin,
    PrimaryPayrollAdminTypedDict,
    PrimarySignatory,
    PrimarySignatoryTypedDict,
    Tier,
)
from .company_address import CompanyAddress, CompanyAddressTypedDict
from .company_attachment import Category, CompanyAttachment, CompanyAttachmentTypedDict
from .company_bank_account import (
    AccountType,
    CompanyBankAccount,
    CompanyBankAccountTypedDict,
    PlaidStatus,
    VerificationStatus,
    VerificationType,
)
from .company_benefit import CompanyBenefit, CompanyBenefitTypedDict
from .company_benefit_with_employee_benefits import (
    CompanyBenefitWithEmployeeBenefits,
    CompanyBenefitWithEmployeeBenefitsContribution,
    CompanyBenefitWithEmployeeBenefitsContributionTypedDict,
    CompanyBenefitWithEmployeeBenefitsTypedDict,
    CompanyBenefitWithEmployeeBenefitsValue,
    CompanyBenefitWithEmployeeBenefitsValue2,
    CompanyBenefitWithEmployeeBenefitsValue2TypedDict,
    CompanyBenefitWithEmployeeBenefitsValueTiers,
    CompanyBenefitWithEmployeeBenefitsValueTiersTypedDict,
    CompanyBenefitWithEmployeeBenefitsValueTypedDict,
    EmployeeBenefitsModel,
    EmployeeBenefitsModelTypedDict,
)
from .company_custom_field import CompanyCustomField, CompanyCustomFieldTypedDict
from .company_custom_field_list import (
    CompanyCustomFieldList,
    CompanyCustomFieldListTypedDict,
)
from .company_onboarding_status import (
    CompanyOnboardingStatus,
    CompanyOnboardingStatusTypedDict,
    ID,
    OnboardingStep,
    OnboardingStepTypedDict,
    Requirements,
)
from .compensation import (
    Compensation,
    CompensationTypedDict,
    MinimumWages,
    MinimumWagesTypedDict,
    PaymentUnit,
)
from .contractor import (
    Address,
    AddressTypedDict,
    Contractor,
    ContractorOnboardingStatus1,
    ContractorPaymentMethod1,
    ContractorType,
    ContractorTypedDict,
    WageType,
)
from .contractor_address import ContractorAddress, ContractorAddressTypedDict
from .contractor_bank_account import (
    ContractorBankAccount,
    ContractorBankAccountAccountType,
    ContractorBankAccountTypedDict,
)
from .contractor_onboarding_status import (
    ContractorOnboardingStatus,
    ContractorOnboardingStatusOnboardingStatus,
    ContractorOnboardingStatusOnboardingStep,
    ContractorOnboardingStatusOnboardingStepTypedDict,
    ContractorOnboardingStatusTypedDict,
)
from .contractor_payment import (
    ContractorPayment,
    ContractorPaymentPaymentMethod,
    ContractorPaymentStatus,
    ContractorPaymentTypedDict,
    ContractorPaymentWageType,
)
from .contractor_payment_for_group import (
    ContractorPaymentForGroup,
    ContractorPaymentForGroupPaymentMethod,
    ContractorPaymentForGroupStatus,
    ContractorPaymentForGroupTypedDict,
    ContractorPaymentForGroupWageType,
)
from .contractor_payment_group import (
    ContractorPaymentGroup,
    ContractorPaymentGroupStatus,
    ContractorPaymentGroupTotals,
    ContractorPaymentGroupTotalsTypedDict,
    ContractorPaymentGroupTypedDict,
)
from .contractor_payment_group_minimal import (
    ContractorPaymentGroupMinimal,
    ContractorPaymentGroupMinimalStatus,
    ContractorPaymentGroupMinimalTotals,
    ContractorPaymentGroupMinimalTotalsTypedDict,
    ContractorPaymentGroupMinimalTypedDict,
)
from .contractor_payment_method import (
    ContractorPaymentMethod,
    ContractorPaymentMethodSplitBy,
    ContractorPaymentMethodType,
    ContractorPaymentMethodTypedDict,
)
from .contractor_payment_receipt import (
    ContractorPaymentReceipt,
    ContractorPaymentReceiptLicensee,
    ContractorPaymentReceiptLicenseeTypedDict,
    ContractorPaymentReceiptTotals,
    ContractorPaymentReceiptTotalsTypedDict,
    ContractorPaymentReceiptTypedDict,
    ContractorPaymentsModel,
    ContractorPaymentsModelTypedDict,
)
from .contractor_payment_summary import (
    ContractorPaymentSummary,
    ContractorPaymentSummaryContractorPayments,
    ContractorPaymentSummaryContractorPaymentsTypedDict,
    ContractorPaymentSummaryTypedDict,
    Total,
    TotalTypedDict,
)
from .contractor_payment_summary_by_dates import (
    ContractorPaymentSummaryByDates,
    ContractorPaymentSummaryByDatesContractorPayments,
    ContractorPaymentSummaryByDatesContractorPaymentsTypedDict,
    ContractorPaymentSummaryByDatesTotal,
    ContractorPaymentSummaryByDatesTotalTypedDict,
    ContractorPaymentSummaryByDatesTypedDict,
)
from .create_report import CreateReport, CreateReportTypedDict
from .custom_field_type import CustomFieldType
from .delete_companies_company_uuid_holiday_pay_policyop import (
    DeleteCompaniesCompanyUUIDHolidayPayPolicyRequest,
    DeleteCompaniesCompanyUUIDHolidayPayPolicyRequestTypedDict,
)
from .delete_departmentop import (
    DeleteDepartmentRequest,
    DeleteDepartmentRequestTypedDict,
)
from .delete_v1_companies_company_id_contractor_payment_contractor_paymentop import (
    DeleteV1CompaniesCompanyIDContractorPaymentContractorPaymentRequest,
    DeleteV1CompaniesCompanyIDContractorPaymentContractorPaymentRequestTypedDict,
)
from .delete_v1_companies_company_id_earning_types_earning_type_uuidop import (
    DeleteV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequest,
    DeleteV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequestTypedDict,
)
from .delete_v1_companies_company_id_payrollsop import (
    DeleteV1CompaniesCompanyIDPayrollsRequest,
    DeleteV1CompaniesCompanyIDPayrollsRequestTypedDict,
)
from .delete_v1_companies_company_uuid_signatories_signatory_uuidop import (
    DeleteV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDRequest,
    DeleteV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDRequestTypedDict,
)
from .delete_v1_company_benefits_company_benefit_idop import (
    Base,
    BaseTypedDict,
    DeleteV1CompanyBenefitsCompanyBenefitIDErrors,
    DeleteV1CompanyBenefitsCompanyBenefitIDErrorsTypedDict,
    DeleteV1CompanyBenefitsCompanyBenefitIDRequest,
    DeleteV1CompanyBenefitsCompanyBenefitIDRequestTypedDict,
    DeleteV1CompanyBenefitsCompanyBenefitIDResponseBody,
    DeleteV1CompanyBenefitsCompanyBenefitIDResponseBodyData,
)
from .delete_v1_compensations_compensation_idop import (
    DeleteV1CompensationsCompensationIDRequest,
    DeleteV1CompensationsCompensationIDRequestTypedDict,
)
from .delete_v1_contractor_payment_groups_contractor_payment_group_idop import (
    DeleteV1ContractorPaymentGroupsContractorPaymentGroupIDRequest,
    DeleteV1ContractorPaymentGroupsContractorPaymentGroupIDRequestTypedDict,
)
from .delete_v1_contractors_contractor_uuidop import (
    DeleteV1ContractorsContractorUUIDRequest,
    DeleteV1ContractorsContractorUUIDRequestTypedDict,
)
from .delete_v1_employee_benefits_employee_benefit_idop import (
    DeleteV1EmployeeBenefitsEmployeeBenefitIDRequest,
    DeleteV1EmployeeBenefitsEmployeeBenefitIDRequestTypedDict,
)
from .delete_v1_employeeop import (
    DeleteV1EmployeeRequest,
    DeleteV1EmployeeRequestTypedDict,
)
from .delete_v1_employees_employee_id_bank_accounts_bank_account_idop import (
    DeleteV1EmployeesEmployeeIDBankAccountsBankAccountIDRequest,
    DeleteV1EmployeesEmployeeIDBankAccountsBankAccountIDRequestTypedDict,
)
from .delete_v1_employees_employee_id_i9_authorization_documents_document_idop import (
    DeleteV1EmployeesEmployeeIDI9AuthorizationDocumentsDocumentIDRequest,
    DeleteV1EmployeesEmployeeIDI9AuthorizationDocumentsDocumentIDRequestTypedDict,
)
from .delete_v1_employees_employee_id_rehireop import (
    DeleteV1EmployeesEmployeeIDRehireRequest,
    DeleteV1EmployeesEmployeeIDRehireRequestTypedDict,
)
from .delete_v1_employees_employee_id_terminationsop import (
    DeleteV1EmployeesEmployeeIDTerminationsRequest,
    DeleteV1EmployeesEmployeeIDTerminationsRequestTypedDict,
)
from .delete_v1_external_payrollop import (
    DeleteV1ExternalPayrollRequest,
    DeleteV1ExternalPayrollRequestTypedDict,
)
from .delete_v1_home_addresses_home_address_uuidop import (
    DeleteV1HomeAddressesHomeAddressUUIDRequest,
    DeleteV1HomeAddressesHomeAddressUUIDRequestTypedDict,
)
from .delete_v1_jobs_job_idop import (
    DeleteV1JobsJobIDRequest,
    DeleteV1JobsJobIDRequestTypedDict,
)
from .delete_v1_webhook_subscription_uuidop import (
    DeleteV1WebhookSubscriptionUUIDRequest,
    DeleteV1WebhookSubscriptionUUIDRequestTypedDict,
    DeleteV1WebhookSubscriptionUUIDSecurity,
    DeleteV1WebhookSubscriptionUUIDSecurityTypedDict,
)
from .delete_v1_work_addresses_work_address_uuidop import (
    DeleteV1WorkAddressesWorkAddressUUIDRequest,
    DeleteV1WorkAddressesWorkAddressUUIDRequestTypedDict,
)
from .department import (
    ContractorsModel,
    ContractorsModelTypedDict,
    Department,
    DepartmentEmployees,
    DepartmentEmployeesTypedDict,
    DepartmentTypedDict,
)
from .document import (
    Document,
    DocumentTypedDict,
    Fields,
    FieldsTypedDict,
    Pages,
    PagesTypedDict,
    RecipientType,
)
from .document_pdf import DocumentPdf, DocumentPdfTypedDict
from .document_signed import (
    DocumentSigned,
    DocumentSignedRecipientType,
    DocumentSignedTypedDict,
)
from .document_type import DocumentType
from .earning_type import EarningType, EarningTypeTypedDict
from .earning_type_list import EarningTypeList, EarningTypeListTypedDict
from .employee import (
    CurrentEmploymentStatus,
    Employee,
    EmployeeTypedDict,
    OnboardingDocumentsConfig,
    OnboardingDocumentsConfigTypedDict,
    OnboardingStatus,
    PaymentMethod,
)
from .employee_address import EmployeeAddress, EmployeeAddressTypedDict
from .employee_bank_account import (
    EmployeeBankAccount,
    EmployeeBankAccountAccountType,
    EmployeeBankAccountTypedDict,
)
from .employee_benefit import (
    Contribution,
    ContributionTypedDict,
    DeductionReducesTaxableIncome,
    EmployeeBenefit,
    EmployeeBenefitTypedDict,
    EmployeeBenefitValue,
    EmployeeBenefitValueTypedDict,
    Tiers,
    TiersTypedDict,
    Two,
    TwoTypedDict,
)
from .employee_benefit_for_company_benefit import (
    EmployeeBenefitForCompanyBenefit,
    EmployeeBenefitForCompanyBenefitContribution,
    EmployeeBenefitForCompanyBenefitContributionTypedDict,
    EmployeeBenefitForCompanyBenefitDeductionReducesTaxableIncome,
    EmployeeBenefitForCompanyBenefitTypedDict,
    EmployeeBenefitForCompanyBenefitValue,
    EmployeeBenefitForCompanyBenefitValueTypedDict,
    Value2,
    Value2TypedDict,
    ValueTiers,
    ValueTiersTypedDict,
)
from .employee_custom_field import EmployeeCustomField, EmployeeCustomFieldTypedDict
from .employee_federal_tax import (
    EmployeeFederalTax,
    EmployeeFederalTaxTypedDict,
    W4DataType,
)
from .employee_onboarding_document import (
    EmployeeOnboardingDocument,
    EmployeeOnboardingDocumentTypedDict,
)
from .employee_onboarding_status import (
    EmployeeOnboardingStatus,
    EmployeeOnboardingStatusOnboardingStep,
    EmployeeOnboardingStatusOnboardingStepTypedDict,
    EmployeeOnboardingStatusTypedDict,
)
from .employee_pay_stub import EmployeePayStub, EmployeePayStubTypedDict
from .employee_payment_method import (
    EmployeePaymentMethod,
    EmployeePaymentMethodType,
    EmployeePaymentMethodTypedDict,
    SplitBy,
)
from .employee_state_tax import EmployeeStateTax, EmployeeStateTaxTypedDict
from .employee_state_tax_answer import (
    EmployeeStateTaxAnswer,
    EmployeeStateTaxAnswerTypedDict,
    Value,
    ValueTypedDict,
)
from .employee_state_tax_input_question_format import (
    EmployeeStateTaxInputQuestionFormat,
    EmployeeStateTaxInputQuestionFormatTypedDict,
    EmployeeStateTaxInputQuestionFormatValue,
    EmployeeStateTaxInputQuestionFormatValueTypedDict,
    Options,
    OptionsTypedDict,
)
from .employee_state_tax_question import (
    EmployeeStateTaxQuestion,
    EmployeeStateTaxQuestionTypedDict,
)
from .employee_work_address import EmployeeWorkAddress, EmployeeWorkAddressTypedDict
from .employment_history_list import (
    EmploymentHistoryList,
    EmploymentHistoryListEmploymentStatus,
    EmploymentHistoryListTypedDict,
)
from .entity_error_object import (
    EntityErrorObject,
    EntityErrorObjectTypedDict,
    Metadata,
    MetadataTypedDict,
)
from .event import Event, EventTypedDict, ResourceType
from .external_payroll import (
    ApplicableBenefits,
    ApplicableBenefitsTypedDict,
    ApplicableEarnings,
    ApplicableEarningsTypedDict,
    ApplicableTaxes,
    ApplicableTaxesTypedDict,
    Earnings,
    EarningsTypedDict,
    ExternalPayroll,
    ExternalPayrollBenefits,
    ExternalPayrollBenefitsTypedDict,
    ExternalPayrollItems,
    ExternalPayrollItemsTypedDict,
    ExternalPayrollMetadata,
    ExternalPayrollMetadataTypedDict,
    ExternalPayrollTaxes,
    ExternalPayrollTaxesTypedDict,
    ExternalPayrollTypedDict,
    Status,
)
from .external_payroll_basic import (
    ExternalPayrollBasic,
    ExternalPayrollBasicStatus,
    ExternalPayrollBasicTypedDict,
)
from .external_payroll_tax_suggestions import (
    ExternalPayrollTaxSuggestions,
    ExternalPayrollTaxSuggestionsTypedDict,
    TaxSuggestions,
    TaxSuggestionsTypedDict,
)
from .fast_payment_limit_required_body import (
    FastPaymentLimitRequiredBody,
    FastPaymentLimitRequiredBodyTypedDict,
)
from .federal_tax_details import FederalTaxDetails, FederalTaxDetailsTypedDict
from .flow import Flow, FlowTypedDict
from .flsa_status_type import FlsaStatusType
from .form import Form, FormTypedDict
from .form_1099 import Form1099, Form1099TypedDict
from .form_pdf import FormPdf, FormPdfTypedDict
from .garnishment import Garnishment, GarnishmentType, GarnishmentTypedDict
from .garnishment_child_support import (
    GarnishmentChildSupport,
    GarnishmentChildSupportTypedDict,
    PaymentPeriod,
)
from .generated_document import (
    GeneratedDocument,
    GeneratedDocumentStatus,
    GeneratedDocumentTypedDict,
)
from .get_ach_transactionsop import (
    GetAchTransactionsRequest,
    GetAchTransactionsRequestTypedDict,
)
from .get_companies_company_uuid_contractor_payments_previewop import (
    CheckDate,
    CheckDateTypedDict,
    GetCompaniesCompanyUUIDContractorPaymentsPreviewBase,
    GetCompaniesCompanyUUIDContractorPaymentsPreviewBaseTypedDict,
    GetCompaniesCompanyUUIDContractorPaymentsPreviewContractorPayments,
    GetCompaniesCompanyUUIDContractorPaymentsPreviewContractorPaymentsResponseBody,
    GetCompaniesCompanyUUIDContractorPaymentsPreviewContractorPaymentsResponseBodyData,
    GetCompaniesCompanyUUIDContractorPaymentsPreviewContractorPaymentsTypedDict,
    GetCompaniesCompanyUUIDContractorPaymentsPreviewErrors,
    GetCompaniesCompanyUUIDContractorPaymentsPreviewErrorsTypedDict,
    GetCompaniesCompanyUUIDContractorPaymentsPreviewRequest,
    GetCompaniesCompanyUUIDContractorPaymentsPreviewRequestBody,
    GetCompaniesCompanyUUIDContractorPaymentsPreviewRequestBodyTypedDict,
    GetCompaniesCompanyUUIDContractorPaymentsPreviewRequestTypedDict,
    GetCompaniesCompanyUUIDContractorPaymentsPreviewResponseBody,
    GetCompaniesCompanyUUIDContractorPaymentsPreviewResponseBodyTypedDict,
)
from .get_companies_company_uuid_holiday_pay_policyop import (
    GetCompaniesCompanyUUIDHolidayPayPolicyRequest,
    GetCompaniesCompanyUUIDHolidayPayPolicyRequestTypedDict,
)
from .get_companies_company_uuid_paid_holidaysop import (
    GetCompaniesCompanyUUIDPaidHolidaysRequest,
    GetCompaniesCompanyUUIDPaidHolidaysRequestBody,
    GetCompaniesCompanyUUIDPaidHolidaysRequestBodyTypedDict,
    GetCompaniesCompanyUUIDPaidHolidaysRequestTypedDict,
)
from .get_companies_company_uuid_report_templates_report_typeop import (
    GetCompaniesCompanyUUIDReportTemplatesReportTypeRequest,
    GetCompaniesCompanyUUIDReportTemplatesReportTypeRequestTypedDict,
)
from .get_companies_company_uuid_time_off_policiesop import (
    GetCompaniesCompanyUUIDTimeOffPoliciesRequest,
    GetCompaniesCompanyUUIDTimeOffPoliciesRequestTypedDict,
)
from .get_companies_company_uuid_wire_in_request_uuidop import (
    GetCompaniesCompanyUUIDWireInRequestUUIDRequest,
    GetCompaniesCompanyUUIDWireInRequestUUIDRequestTypedDict,
)
from .get_companies_departmentsop import (
    GetCompaniesDepartmentsRequest,
    GetCompaniesDepartmentsRequestTypedDict,
)
from .get_departmentop import GetDepartmentRequest, GetDepartmentRequestTypedDict
from .get_employee_ytd_benefit_amounts_from_different_companyop import (
    GetEmployeeYtdBenefitAmountsFromDifferentCompanyRequest,
    GetEmployeeYtdBenefitAmountsFromDifferentCompanyRequestTypedDict,
)
from .get_eventsop import (
    GetEventsRequest,
    GetEventsRequestTypedDict,
    GetEventsSecurity,
    GetEventsSecurityTypedDict,
)
from .get_invoices_invoice_periodop import (
    GetInvoicesInvoicePeriodRequest,
    GetInvoicesInvoicePeriodRequestTypedDict,
    GetInvoicesInvoicePeriodSecurity,
    GetInvoicesInvoicePeriodSecurityTypedDict,
)
from .get_notifications_notification_uuidop import (
    GetNotificationsNotificationUUIDRequest,
    GetNotificationsNotificationUUIDRequestTypedDict,
)
from .get_recovery_casesop import (
    GetRecoveryCasesRequest,
    GetRecoveryCasesRequestTypedDict,
)
from .get_reports_report_uuidop import (
    GetReportsReportUUIDRequest,
    GetReportsReportUUIDRequestTypedDict,
)
from .get_time_off_policies_time_off_policy_uuidop import (
    GetTimeOffPoliciesTimeOffPolicyUUIDRequest,
    GetTimeOffPoliciesTimeOffPolicyUUIDRequestTypedDict,
)
from .get_v1_benefits_benefit_idop import (
    GetV1BenefitsBenefitIDRequest,
    GetV1BenefitsBenefitIDRequestTypedDict,
)
from .get_v1_benefits_benefits_id_requirementsop import (
    GetV1BenefitsBenefitsIDRequirementsRequest,
    GetV1BenefitsBenefitsIDRequirementsRequestTypedDict,
)
from .get_v1_benefits_company_benefit_id_summaryop import (
    GetV1BenefitsCompanyBenefitIDSummaryRequest,
    GetV1BenefitsCompanyBenefitIDSummaryRequestTypedDict,
)
from .get_v1_benefitsop import GetV1BenefitsRequest, GetV1BenefitsRequestTypedDict
from .get_v1_companies_attachment_urlop import (
    GetV1CompaniesAttachmentURLRequest,
    GetV1CompaniesAttachmentURLRequestTypedDict,
    GetV1CompaniesAttachmentURLResponseBody,
    GetV1CompaniesAttachmentURLResponseBodyTypedDict,
)
from .get_v1_companies_attachmentop import (
    GetV1CompaniesAttachmentRequest,
    GetV1CompaniesAttachmentRequestTypedDict,
)
from .get_v1_companies_attachmentsop import (
    GetV1CompaniesAttachmentsRequest,
    GetV1CompaniesAttachmentsRequestTypedDict,
)
from .get_v1_companies_company_id_adminsop import (
    GetV1CompaniesCompanyIDAdminsRequest,
    GetV1CompaniesCompanyIDAdminsRequestTypedDict,
)
from .get_v1_companies_company_id_bank_accountsop import (
    GetV1CompaniesCompanyIDBankAccountsRequest,
    GetV1CompaniesCompanyIDBankAccountsRequestTypedDict,
)
from .get_v1_companies_company_id_company_benefitsop import (
    GetV1CompaniesCompanyIDCompanyBenefitsRequest,
    GetV1CompaniesCompanyIDCompanyBenefitsRequestTypedDict,
)
from .get_v1_companies_company_id_contractor_payment_contractor_paymentop import (
    GetV1CompaniesCompanyIDContractorPaymentContractorPaymentRequest,
    GetV1CompaniesCompanyIDContractorPaymentContractorPaymentRequestTypedDict,
)
from .get_v1_companies_company_id_contractor_payment_groupsop import (
    GetV1CompaniesCompanyIDContractorPaymentGroupsRequest,
    GetV1CompaniesCompanyIDContractorPaymentGroupsRequestTypedDict,
)
from .get_v1_companies_company_id_contractor_paymentsop import (
    GetV1CompaniesCompanyIDContractorPaymentsRequest,
    GetV1CompaniesCompanyIDContractorPaymentsRequestTypedDict,
    GetV1CompaniesCompanyIDContractorPaymentsResponseBody,
    GetV1CompaniesCompanyIDContractorPaymentsResponseBodyTypedDict,
)
from .get_v1_companies_company_id_custom_fieldsop import (
    GetV1CompaniesCompanyIDCustomFieldsRequest,
    GetV1CompaniesCompanyIDCustomFieldsRequestTypedDict,
)
from .get_v1_companies_company_id_earning_typesop import (
    GetV1CompaniesCompanyIDEarningTypesRequest,
    GetV1CompaniesCompanyIDEarningTypesRequestTypedDict,
)
from .get_v1_companies_company_id_employeesop import (
    GetV1CompaniesCompanyIDEmployeesRequest,
    GetV1CompaniesCompanyIDEmployeesRequestTypedDict,
    Include,
)
from .get_v1_companies_company_id_federal_tax_detailsop import (
    GetV1CompaniesCompanyIDFederalTaxDetailsRequest,
    GetV1CompaniesCompanyIDFederalTaxDetailsRequestTypedDict,
)
from .get_v1_companies_company_id_locationsop import (
    GetV1CompaniesCompanyIDLocationsRequest,
    GetV1CompaniesCompanyIDLocationsRequestTypedDict,
)
from .get_v1_companies_company_id_pay_periodsop import (
    GetV1CompaniesCompanyIDPayPeriodsRequest,
    GetV1CompaniesCompanyIDPayPeriodsRequestTypedDict,
)
from .get_v1_companies_company_id_pay_schedules_assignmentsop import (
    GetV1CompaniesCompanyIDPaySchedulesAssignmentsRequest,
    GetV1CompaniesCompanyIDPaySchedulesAssignmentsRequestTypedDict,
)
from .get_v1_companies_company_id_pay_schedules_pay_schedule_idop import (
    GetV1CompaniesCompanyIDPaySchedulesPayScheduleIDRequest,
    GetV1CompaniesCompanyIDPaySchedulesPayScheduleIDRequestTypedDict,
)
from .get_v1_companies_company_id_pay_schedules_previewop import (
    GetV1CompaniesCompanyIDPaySchedulesPreviewRequest,
    GetV1CompaniesCompanyIDPaySchedulesPreviewRequestTypedDict,
    GetV1CompaniesCompanyIDPaySchedulesPreviewResponseBody,
    GetV1CompaniesCompanyIDPaySchedulesPreviewResponseBodyTypedDict,
    PayPeriods,
    PayPeriodsTypedDict,
    QueryParamFrequency,
)
from .get_v1_companies_company_id_pay_schedulesop import (
    GetV1CompaniesCompanyIDPaySchedulesRequest,
    GetV1CompaniesCompanyIDPaySchedulesRequestTypedDict,
)
from .get_v1_companies_company_id_payroll_reversalsop import (
    GetV1CompaniesCompanyIDPayrollReversalsRequest,
    GetV1CompaniesCompanyIDPayrollReversalsRequestTypedDict,
)
from .get_v1_companies_company_id_payrolls_payroll_idop import (
    GetV1CompaniesCompanyIDPayrollsPayrollIDQueryParamInclude,
    GetV1CompaniesCompanyIDPayrollsPayrollIDRequest,
    GetV1CompaniesCompanyIDPayrollsPayrollIDRequestTypedDict,
)
from .get_v1_companies_company_id_payrollsop import (
    GetV1CompaniesCompanyIDPayrollsQueryParamInclude,
    GetV1CompaniesCompanyIDPayrollsRequest,
    GetV1CompaniesCompanyIDPayrollsRequestTypedDict,
    PayrollTypes,
    ProcessingStatuses,
)
from .get_v1_companies_company_id_unprocessed_termination_pay_periodsop import (
    GetV1CompaniesCompanyIDUnprocessedTerminationPayPeriodsRequest,
    GetV1CompaniesCompanyIDUnprocessedTerminationPayPeriodsRequestTypedDict,
)
from .get_v1_companies_company_uuid_contractorsop import (
    GetV1CompaniesCompanyUUIDContractorsRequest,
    GetV1CompaniesCompanyUUIDContractorsRequestTypedDict,
)
from .get_v1_companies_company_uuid_signatoriesop import (
    GetV1CompaniesCompanyUUIDSignatoriesRequest,
    GetV1CompaniesCompanyUUIDSignatoriesRequestTypedDict,
)
from .get_v1_companies_company_uuid_tax_requirements_stateop import (
    GetV1CompaniesCompanyUUIDTaxRequirementsStateRequest,
    GetV1CompaniesCompanyUUIDTaxRequirementsStateRequestTypedDict,
)
from .get_v1_companies_company_uuid_tax_requirementsop import (
    GetV1CompaniesCompanyUUIDTaxRequirementsRequest,
    GetV1CompaniesCompanyUUIDTaxRequirementsRequestTypedDict,
    ResponseBody,
    ResponseBodyTypedDict,
)
from .get_v1_companies_payroll_blockers_company_uuidop import (
    GetV1CompaniesPayrollBlockersCompanyUUIDRequest,
    GetV1CompaniesPayrollBlockersCompanyUUIDRequestTypedDict,
)
from .get_v1_companiesop import GetV1CompaniesRequest, GetV1CompaniesRequestTypedDict
from .get_v1_company_benefits_company_benefit_id_employee_benefitsop import (
    GetV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequest,
    GetV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestTypedDict,
)
from .get_v1_company_benefits_company_benefit_idop import (
    GetV1CompanyBenefitsCompanyBenefitIDRequest,
    GetV1CompanyBenefitsCompanyBenefitIDRequestTypedDict,
)
from .get_v1_company_external_payrollsop import (
    GetV1CompanyExternalPayrollsRequest,
    GetV1CompanyExternalPayrollsRequestTypedDict,
)
from .get_v1_company_finish_onboardingop import (
    GetV1CompanyFinishOnboardingRequest,
    GetV1CompanyFinishOnboardingRequestTypedDict,
)
from .get_v1_company_form_pdfop import (
    GetV1CompanyFormPdfRequest,
    GetV1CompanyFormPdfRequestTypedDict,
)
from .get_v1_company_formop import (
    GetV1CompanyFormRequest,
    GetV1CompanyFormRequestTypedDict,
)
from .get_v1_company_formsop import (
    GetV1CompanyFormsRequest,
    GetV1CompanyFormsRequestTypedDict,
)
from .get_v1_company_industryop import (
    GetV1CompanyIndustryRequest,
    GetV1CompanyIndustryRequestTypedDict,
)
from .get_v1_company_onboarding_statusop import (
    GetV1CompanyOnboardingStatusRequest,
    GetV1CompanyOnboardingStatusRequestTypedDict,
)
from .get_v1_company_payment_configsop import (
    GetV1CompanyPaymentConfigsRequest,
    GetV1CompanyPaymentConfigsRequestTypedDict,
)
from .get_v1_compensations_compensation_idop import (
    GetV1CompensationsCompensationIDRequest,
    GetV1CompensationsCompensationIDRequestTypedDict,
)
from .get_v1_contractor_document_pdfop import (
    GetV1ContractorDocumentPdfRequest,
    GetV1ContractorDocumentPdfRequestTypedDict,
)
from .get_v1_contractor_documentop import (
    GetV1ContractorDocumentRequest,
    GetV1ContractorDocumentRequestTypedDict,
)
from .get_v1_contractor_documentsop import (
    GetV1ContractorDocumentsRequest,
    GetV1ContractorDocumentsRequestTypedDict,
)
from .get_v1_contractor_form_pdfop import (
    GetV1ContractorFormPdfRequest,
    GetV1ContractorFormPdfRequestTypedDict,
)
from .get_v1_contractor_formop import (
    GetV1ContractorFormRequest,
    GetV1ContractorFormRequestTypedDict,
)
from .get_v1_contractor_formsop import (
    GetV1ContractorFormsRequest,
    GetV1ContractorFormsRequestTypedDict,
)
from .get_v1_contractor_payment_groups_contractor_payment_group_idop import (
    GetV1ContractorPaymentGroupsContractorPaymentGroupIDRequest,
    GetV1ContractorPaymentGroupsContractorPaymentGroupIDRequestTypedDict,
)
from .get_v1_contractor_payments_contractor_payment_uuid_fundop import (
    GetV1ContractorPaymentsContractorPaymentUUIDFundRequest,
    GetV1ContractorPaymentsContractorPaymentUUIDFundRequestTypedDict,
)
from .get_v1_contractor_payments_contractor_payment_uuid_receiptop import (
    GetV1ContractorPaymentsContractorPaymentUUIDReceiptRequest,
    GetV1ContractorPaymentsContractorPaymentUUIDReceiptRequestTypedDict,
)
from .get_v1_contractors_contractor_uuid_addressop import (
    GetV1ContractorsContractorUUIDAddressRequest,
    GetV1ContractorsContractorUUIDAddressRequestTypedDict,
)
from .get_v1_contractors_contractor_uuid_bank_accountsop import (
    GetV1ContractorsContractorUUIDBankAccountsRequest,
    GetV1ContractorsContractorUUIDBankAccountsRequestTypedDict,
)
from .get_v1_contractors_contractor_uuid_onboarding_statusop import (
    GetV1ContractorsContractorUUIDOnboardingStatusRequest,
    GetV1ContractorsContractorUUIDOnboardingStatusRequestTypedDict,
)
from .get_v1_contractors_contractor_uuid_payment_methodop import (
    GetV1ContractorsContractorUUIDPaymentMethodRequest,
    GetV1ContractorsContractorUUIDPaymentMethodRequestTypedDict,
)
from .get_v1_contractors_contractor_uuidop import (
    GetV1ContractorsContractorUUIDRequest,
    GetV1ContractorsContractorUUIDRequestTypedDict,
)
from .get_v1_employee_benefits_employee_benefit_idop import (
    GetV1EmployeeBenefitsEmployeeBenefitIDRequest,
    GetV1EmployeeBenefitsEmployeeBenefitIDRequestTypedDict,
)
from .get_v1_employee_form_pdfop import (
    GetV1EmployeeFormPdfRequest,
    GetV1EmployeeFormPdfRequestTypedDict,
)
from .get_v1_employee_formop import (
    GetV1EmployeeFormRequest,
    GetV1EmployeeFormRequestTypedDict,
)
from .get_v1_employee_formsop import (
    GetV1EmployeeFormsRequest,
    GetV1EmployeeFormsRequestTypedDict,
)
from .get_v1_employees_employee_id_bank_accountsop import (
    GetV1EmployeesEmployeeIDBankAccountsRequest,
    GetV1EmployeesEmployeeIDBankAccountsRequestTypedDict,
)
from .get_v1_employees_employee_id_custom_fieldsop import (
    GetV1EmployeesEmployeeIDCustomFieldsRequest,
    GetV1EmployeesEmployeeIDCustomFieldsRequestTypedDict,
    GetV1EmployeesEmployeeIDCustomFieldsResponseBody,
    GetV1EmployeesEmployeeIDCustomFieldsResponseBodyTypedDict,
)
from .get_v1_employees_employee_id_employee_benefitsop import (
    GetV1EmployeesEmployeeIDEmployeeBenefitsRequest,
    GetV1EmployeesEmployeeIDEmployeeBenefitsRequestTypedDict,
)
from .get_v1_employees_employee_id_employment_historyop import (
    GetV1EmployeesEmployeeIDEmploymentHistoryRequest,
    GetV1EmployeesEmployeeIDEmploymentHistoryRequestTypedDict,
)
from .get_v1_employees_employee_id_federal_taxesop import (
    GetV1EmployeesEmployeeIDFederalTaxesRequest,
    GetV1EmployeesEmployeeIDFederalTaxesRequestTypedDict,
)
from .get_v1_employees_employee_id_garnishmentsop import (
    GetV1EmployeesEmployeeIDGarnishmentsRequest,
    GetV1EmployeesEmployeeIDGarnishmentsRequestTypedDict,
)
from .get_v1_employees_employee_id_home_addressesop import (
    GetV1EmployeesEmployeeIDHomeAddressesRequest,
    GetV1EmployeesEmployeeIDHomeAddressesRequestTypedDict,
)
from .get_v1_employees_employee_id_i9_authorization_document_optionsop import (
    GetV1EmployeesEmployeeIDI9AuthorizationDocumentOptionsRequest,
    GetV1EmployeesEmployeeIDI9AuthorizationDocumentOptionsRequestTypedDict,
)
from .get_v1_employees_employee_id_i9_authorization_documentsop import (
    GetV1EmployeesEmployeeIDI9AuthorizationDocumentsRequest,
    GetV1EmployeesEmployeeIDI9AuthorizationDocumentsRequestTypedDict,
)
from .get_v1_employees_employee_id_i9_authorizationop import (
    GetV1EmployeesEmployeeIDI9AuthorizationRequest,
    GetV1EmployeesEmployeeIDI9AuthorizationRequestTypedDict,
)
from .get_v1_employees_employee_id_jobsop import (
    GetV1EmployeesEmployeeIDJobsQueryParamInclude,
    GetV1EmployeesEmployeeIDJobsRequest,
    GetV1EmployeesEmployeeIDJobsRequestTypedDict,
)
from .get_v1_employees_employee_id_onboarding_statusop import (
    GetV1EmployeesEmployeeIDOnboardingStatusRequest,
    GetV1EmployeesEmployeeIDOnboardingStatusRequestTypedDict,
)
from .get_v1_employees_employee_id_payment_methodop import (
    GetV1EmployeesEmployeeIDPaymentMethodRequest,
    GetV1EmployeesEmployeeIDPaymentMethodRequestTypedDict,
)
from .get_v1_employees_employee_id_rehireop import (
    GetV1EmployeesEmployeeIDRehireRequest,
    GetV1EmployeesEmployeeIDRehireRequestTypedDict,
)
from .get_v1_employees_employee_id_state_taxesop import (
    GetV1EmployeesEmployeeIDStateTaxesRequest,
    GetV1EmployeesEmployeeIDStateTaxesRequestTypedDict,
)
from .get_v1_employees_employee_id_terminationsop import (
    GetV1EmployeesEmployeeIDTerminationsRequest,
    GetV1EmployeesEmployeeIDTerminationsRequestTypedDict,
)
from .get_v1_employees_employee_id_work_addressesop import (
    GetV1EmployeesEmployeeIDWorkAddressesRequest,
    GetV1EmployeesEmployeeIDWorkAddressesRequestTypedDict,
)
from .get_v1_employees_employee_uuid_pay_stubsop import (
    GetV1EmployeesEmployeeUUIDPayStubsRequest,
    GetV1EmployeesEmployeeUUIDPayStubsRequestTypedDict,
)
from .get_v1_employeesop import (
    GetV1EmployeesRequest,
    GetV1EmployeesRequestTypedDict,
    QueryParamInclude,
)
from .get_v1_external_payroll_calculate_taxesop import (
    GetV1ExternalPayrollCalculateTaxesRequest,
    GetV1ExternalPayrollCalculateTaxesRequestTypedDict,
)
from .get_v1_external_payrollop import (
    GetV1ExternalPayrollRequest,
    GetV1ExternalPayrollRequestTypedDict,
)
from .get_v1_garnishments_child_supportop import (
    GetV1GarnishmentsChildSupportRequest,
    GetV1GarnishmentsChildSupportRequestTypedDict,
)
from .get_v1_garnishments_garnishment_idop import (
    GetV1GarnishmentsGarnishmentIDRequest,
    GetV1GarnishmentsGarnishmentIDRequestTypedDict,
)
from .get_v1_generated_documents_document_type_request_uuidop import (
    GetV1GeneratedDocumentsDocumentTypeRequestUUIDRequest,
    GetV1GeneratedDocumentsDocumentTypeRequestUUIDRequestTypedDict,
)
from .get_v1_home_addresses_home_address_uuidop import (
    GetV1HomeAddressesHomeAddressUUIDRequest,
    GetV1HomeAddressesHomeAddressUUIDRequestTypedDict,
)
from .get_v1_jobs_job_id_compensationsop import (
    GetV1JobsJobIDCompensationsQueryParamInclude,
    GetV1JobsJobIDCompensationsRequest,
    GetV1JobsJobIDCompensationsRequestTypedDict,
)
from .get_v1_jobs_job_idop import (
    GetV1JobsJobIDQueryParamInclude,
    GetV1JobsJobIDRequest,
    GetV1JobsJobIDRequestTypedDict,
)
from .get_v1_locations_location_idop import (
    GetV1LocationsLocationIDRequest,
    GetV1LocationsLocationIDRequestTypedDict,
)
from .get_v1_locations_location_uuid_minimum_wagesop import (
    GetV1LocationsLocationUUIDMinimumWagesRequest,
    GetV1LocationsLocationUUIDMinimumWagesRequestTypedDict,
)
from .get_v1_payment_receipts_payrolls_payroll_uuidop import (
    GetV1PaymentReceiptsPayrollsPayrollUUIDRequest,
    GetV1PaymentReceiptsPayrollsPayrollUUIDRequestTypedDict,
)
from .get_v1_payrolls_payroll_uuid_employees_employee_uuid_pay_stubop import (
    GetV1PayrollsPayrollUUIDEmployeesEmployeeUUIDPayStubRequest,
    GetV1PayrollsPayrollUUIDEmployeesEmployeeUUIDPayStubRequestTypedDict,
)
from .get_v1_tax_liabilitiesop import (
    GetV1TaxLiabilitiesRequest,
    GetV1TaxLiabilitiesRequestTypedDict,
)
from .get_v1_token_infoop import (
    GetV1TokenInfoRequest,
    GetV1TokenInfoRequestTypedDict,
    GetV1TokenInfoResponseBody,
    GetV1TokenInfoResponseBodyTypedDict,
    GetV1TokenInfoType,
    Resource,
    ResourceOwner,
    ResourceOwnerTypedDict,
    ResourceTypedDict,
)
from .get_v1_webhook_subscription_uuidop import (
    GetV1WebhookSubscriptionUUIDRequest,
    GetV1WebhookSubscriptionUUIDRequestTypedDict,
    GetV1WebhookSubscriptionUUIDSecurity,
    GetV1WebhookSubscriptionUUIDSecurityTypedDict,
)
from .get_v1_webhook_subscription_verification_token_uuidop import (
    GetV1WebhookSubscriptionVerificationTokenUUIDRequest,
    GetV1WebhookSubscriptionVerificationTokenUUIDRequestTypedDict,
    GetV1WebhookSubscriptionVerificationTokenUUIDSecurity,
    GetV1WebhookSubscriptionVerificationTokenUUIDSecurityTypedDict,
)
from .get_v1_webhook_subscriptionsop import (
    GetV1WebhookSubscriptionsRequest,
    GetV1WebhookSubscriptionsRequestTypedDict,
    GetV1WebhookSubscriptionsSecurity,
    GetV1WebhookSubscriptionsSecurityTypedDict,
)
from .get_v1_work_addresses_work_address_uuidop import (
    GetV1WorkAddressesWorkAddressUUIDRequest,
    GetV1WorkAddressesWorkAddressUUIDRequestTypedDict,
)
from .get_version_employees_time_off_activitiesop import (
    GetVersionEmployeesTimeOffActivitiesRequest,
    GetVersionEmployeesTimeOffActivitiesRequestTypedDict,
)
from .get_wire_in_requests_wire_in_request_uuidop import (
    GetWireInRequestsWireInRequestUUIDRequest,
    GetWireInRequestsWireInRequestUUIDRequestTypedDict,
)
from .gross_up_pay import GrossUpPay, GrossUpPayTypedDict
from .historical_employee_body import (
    EmployeeStateTaxes,
    EmployeeStateTaxesTypedDict,
    HistoricalEmployeeBody,
    HistoricalEmployeeBodyHomeAddress,
    HistoricalEmployeeBodyHomeAddressTypedDict,
    HistoricalEmployeeBodyJob,
    HistoricalEmployeeBodyJobTypedDict,
    HistoricalEmployeeBodyTermination,
    HistoricalEmployeeBodyTerminationTypedDict,
    HistoricalEmployeeBodyTypedDict,
    WorkAddress,
    WorkAddressTypedDict,
)
from .holiday_pay_policy import (
    ColumbusDay,
    ColumbusDayTypedDict,
    FederalHolidays,
    FederalHolidaysTypedDict,
    HolidayPayPolicy,
    HolidayPayPolicyEmployees,
    HolidayPayPolicyEmployeesTypedDict,
    HolidayPayPolicyTypedDict,
    IndependenceDay,
    IndependenceDayTypedDict,
    Juneteenth,
    JuneteenthTypedDict,
    LaborDay,
    LaborDayTypedDict,
    MemorialDay,
    MemorialDayTypedDict,
    MlkDay,
    MlkDayTypedDict,
    NewYearsDay,
    NewYearsDayTypedDict,
    PresidentsDay,
    PresidentsDayTypedDict,
    Thanksgiving,
    ThanksgivingTypedDict,
    VeteransDay,
    VeteransDayTypedDict,
)
from .i9_authorization import (
    AuthorizationStatus,
    I9Authorization,
    I9AuthorizationDocumentType,
    I9AuthorizationTypedDict,
)
from .i9_authorization_document import (
    I9AuthorizationDocument,
    I9AuthorizationDocumentTypedDict,
)
from .i9_authorization_document_option import (
    I9AuthorizationDocumentOption,
    I9AuthorizationDocumentOptionTypedDict,
    Section,
)
from .industry import Industry, IndustryTypedDict
from .invoice_data import (
    ActiveCompanies,
    ActiveCompaniesTypedDict,
    InvoiceData,
    InvoiceDataTypedDict,
)
from .job import Job, JobTypedDict
from .location import Location, LocationTypedDict
from .metadata_with_multiple_entities import (
    MetadataWithMultipleEntities,
    MetadataWithMultipleEntitiesTypedDict,
)
from .metadata_with_one_entity import (
    MetadataWithOneEntity,
    MetadataWithOneEntityTypedDict,
)
from .minimum_wage import MinimumWage, MinimumWageTypedDict
from .notification import (
    Notification,
    NotificationTypedDict,
    Resources,
    ResourcesTypedDict,
)
from .off_cycle_reason_type import OffCycleReasonType
from .paid_holidays import PaidHolidays, PaidHolidaysTypedDict, Schema, SchemaTypedDict
from .paid_time_off import Name, PaidTimeOff, PaidTimeOffTypedDict
from .pay_period import (
    PayPeriod,
    PayPeriodPayroll,
    PayPeriodPayrollTypedDict,
    PayPeriodTypedDict,
    PayrollType,
)
from .pay_schedule import PaySchedule, PayScheduleTypedDict
from .pay_schedule_assignment import (
    PayScheduleAssignment,
    PayScheduleAssignmentTypedDict,
    Type,
)
from .pay_schedule_assignment_body import (
    DepartmentsModel,
    DepartmentsModelTypedDict,
    EmployeesModel,
    EmployeesModelTypedDict,
    PayScheduleAssignmentBody,
    PayScheduleAssignmentBodyType,
    PayScheduleAssignmentBodyTypedDict,
)
from .pay_schedule_assignment_department import (
    PayScheduleAssignmentDepartment,
    PayScheduleAssignmentDepartmentTypedDict,
)
from .pay_schedule_assignment_employee import (
    PayScheduleAssignmentEmployee,
    PayScheduleAssignmentEmployeeTypedDict,
)
from .pay_schedule_assignment_employee_change import (
    PayScheduleAssignmentEmployeeChange,
    PayScheduleAssignmentEmployeeChangeTypedDict,
)
from .pay_schedule_assignment_pay_period import (
    PayScheduleAssignmentPayPeriod,
    PayScheduleAssignmentPayPeriodTypedDict,
)
from .pay_schedule_assignment_preview import (
    PayScheduleAssignmentPreview,
    PayScheduleAssignmentPreviewType,
    PayScheduleAssignmentPreviewTypedDict,
)
from .pay_schedule_assignment_transition_pay_period import (
    PayScheduleAssignmentTransitionPayPeriod,
    PayScheduleAssignmentTransitionPayPeriodTypedDict,
)
from .pay_schedule_create_update import (
    PayScheduleCreateUpdate,
    PayScheduleCreateUpdateTypedDict,
)
from .pay_schedule_frequency import PayScheduleFrequency
from .pay_schedule_frequency_create_update import PayScheduleFrequencyCreateUpdate
from .payment_configs import PaymentConfigs, PaymentConfigsTypedDict
from .payment_method_bank_account import (
    PaymentMethodBankAccount,
    PaymentMethodBankAccountTypedDict,
)
from .payment_speed_param import PaymentSpeedParam
from .payment_speed_required_body import (
    PaymentSpeedRequiredBody,
    PaymentSpeedRequiredBodyTypedDict,
)
from .payroll import Payroll, PayrollTypedDict
from .payroll_blocker import PayrollBlocker, PayrollBlockerTypedDict
from .payroll_blockers_error import (
    Errors,
    ErrorsTypedDict,
    PayrollBlockersError,
    PayrollBlockersErrorData,
    PayrollBlockersErrorMetadata,
    PayrollBlockersErrorMetadataTypedDict,
)
from .payroll_check import (
    EmployeeCheckNumberMapping,
    EmployeeCheckNumberMappingTypedDict,
    PayrollCheck,
    PayrollCheckTypedDict,
)
from .payroll_company_taxes_type import (
    PayrollCompanyTaxesType,
    PayrollCompanyTaxesTypeTypedDict,
)
from .payroll_credit_blockers_type import (
    PayrollCreditBlockersType,
    PayrollCreditBlockersTypeMetadata,
    PayrollCreditBlockersTypeMetadataTypedDict,
    PayrollCreditBlockersTypeStatus,
    PayrollCreditBlockersTypeTypedDict,
    PayrollCreditBlockersTypeUnblockOptions,
    PayrollCreditBlockersTypeUnblockOptionsTypedDict,
)
from .payroll_employee_compensations_type import (
    Benefits,
    BenefitsTypedDict,
    Deductions,
    DeductionsTypedDict,
    FixedCompensations,
    FixedCompensationsTypedDict,
    HourlyCompensations,
    HourlyCompensationsTypedDict,
    PayrollEmployeeCompensationsType,
    PayrollEmployeeCompensationsTypePaidTimeOff,
    PayrollEmployeeCompensationsTypePaidTimeOffTypedDict,
    PayrollEmployeeCompensationsTypePaymentMethod,
    PayrollEmployeeCompensationsTypeTypedDict,
    Taxes,
    TaxesTypedDict,
)
from .payroll_fixed_compensation_types_type import (
    PayrollFixedCompensationTypesType,
    PayrollFixedCompensationTypesTypeTypedDict,
)
from .payroll_minimal import PayrollMinimal, PayrollMinimalTypedDict
from .payroll_pay_period_type import PayrollPayPeriodType, PayrollPayPeriodTypeTypedDict
from .payroll_payment_speed_changed_type import (
    PayrollPaymentSpeedChangedType,
    PayrollPaymentSpeedChangedTypeTypedDict,
)
from .payroll_payroll_status_meta_type import (
    PayrollPayrollStatusMetaType,
    PayrollPayrollStatusMetaTypeTypedDict,
)
from .payroll_prepared import PayrollPrepared, PayrollPreparedTypedDict
from .payroll_processing_request import (
    PayrollProcessingRequest,
    PayrollProcessingRequestStatus,
    PayrollProcessingRequestTypedDict,
)
from .payroll_receipt import (
    EmployeeCompensations,
    EmployeeCompensationsTypedDict,
    Licensee,
    LicenseeTypedDict,
    PayrollReceipt,
    PayrollReceiptTaxes,
    PayrollReceiptTaxesTypedDict,
    PayrollReceiptTypedDict,
    Totals,
    TotalsTypedDict,
)
from .payroll_reversal import PayrollReversal, PayrollReversalTypedDict
from .payroll_submission_blockers_type import (
    PayrollSubmissionBlockersType,
    PayrollSubmissionBlockersTypeMetadata,
    PayrollSubmissionBlockersTypeMetadataTypedDict,
    PayrollSubmissionBlockersTypeStatus,
    PayrollSubmissionBlockersTypeTypedDict,
    UnblockOptions,
    UnblockOptionsTypedDict,
)
from .payroll_totals_type import PayrollTotalsType, PayrollTotalsTypeTypedDict
from .payroll_withholding_pay_period_type import PayrollWithholdingPayPeriodType
from .post_companies_company_uuid_holiday_pay_policyop import (
    ChristmasDay,
    ChristmasDayTypedDict,
    PostCompaniesCompanyUUIDHolidayPayPolicyColumbusDay,
    PostCompaniesCompanyUUIDHolidayPayPolicyColumbusDayTypedDict,
    PostCompaniesCompanyUUIDHolidayPayPolicyFederalHolidays,
    PostCompaniesCompanyUUIDHolidayPayPolicyFederalHolidaysTypedDict,
    PostCompaniesCompanyUUIDHolidayPayPolicyIndependenceDay,
    PostCompaniesCompanyUUIDHolidayPayPolicyIndependenceDayTypedDict,
    PostCompaniesCompanyUUIDHolidayPayPolicyJuneteenth,
    PostCompaniesCompanyUUIDHolidayPayPolicyJuneteenthTypedDict,
    PostCompaniesCompanyUUIDHolidayPayPolicyLaborDay,
    PostCompaniesCompanyUUIDHolidayPayPolicyLaborDayTypedDict,
    PostCompaniesCompanyUUIDHolidayPayPolicyMemorialDay,
    PostCompaniesCompanyUUIDHolidayPayPolicyMemorialDayTypedDict,
    PostCompaniesCompanyUUIDHolidayPayPolicyMlkDay,
    PostCompaniesCompanyUUIDHolidayPayPolicyMlkDayTypedDict,
    PostCompaniesCompanyUUIDHolidayPayPolicyNewYearsDay,
    PostCompaniesCompanyUUIDHolidayPayPolicyNewYearsDayTypedDict,
    PostCompaniesCompanyUUIDHolidayPayPolicyPresidentsDay,
    PostCompaniesCompanyUUIDHolidayPayPolicyPresidentsDayTypedDict,
    PostCompaniesCompanyUUIDHolidayPayPolicyRequest,
    PostCompaniesCompanyUUIDHolidayPayPolicyRequestBody,
    PostCompaniesCompanyUUIDHolidayPayPolicyRequestBodyTypedDict,
    PostCompaniesCompanyUUIDHolidayPayPolicyRequestTypedDict,
    PostCompaniesCompanyUUIDHolidayPayPolicyThanksgiving,
    PostCompaniesCompanyUUIDHolidayPayPolicyThanksgivingTypedDict,
    PostCompaniesCompanyUUIDHolidayPayPolicyVeteransDay,
    PostCompaniesCompanyUUIDHolidayPayPolicyVeteransDayTypedDict,
)
from .post_companies_company_uuid_reportsop import (
    Columns,
    EmploymentType,
    FileType,
    Groupings,
    PostCompaniesCompanyUUIDReportsEmploymentStatus,
    PostCompaniesCompanyUUIDReportsPaymentMethod,
    PostCompaniesCompanyUUIDReportsRequest,
    PostCompaniesCompanyUUIDReportsRequestBody,
    PostCompaniesCompanyUUIDReportsRequestBodyTypedDict,
    PostCompaniesCompanyUUIDReportsRequestTypedDict,
)
from .post_companies_company_uuid_time_off_policiesop import (
    PostCompaniesCompanyUUIDTimeOffPoliciesAccrualMethod,
    PostCompaniesCompanyUUIDTimeOffPoliciesRequest,
    PostCompaniesCompanyUUIDTimeOffPoliciesRequestBody,
    PostCompaniesCompanyUUIDTimeOffPoliciesRequestBodyTypedDict,
    PostCompaniesCompanyUUIDTimeOffPoliciesRequestTypedDict,
)
from .post_companies_payroll_skip_company_uuidop import (
    PostCompaniesPayrollSkipCompanyUUIDPayrollType,
    PostCompaniesPayrollSkipCompanyUUIDRequest,
    PostCompaniesPayrollSkipCompanyUUIDRequestBody,
    PostCompaniesPayrollSkipCompanyUUIDRequestBodyTypedDict,
    PostCompaniesPayrollSkipCompanyUUIDRequestTypedDict,
    PostCompaniesPayrollSkipCompanyUUIDResponseBody,
    PostCompaniesPayrollSkipCompanyUUIDResponseBodyUnion,
)
from .post_departmentsop import (
    PostDepartmentsRequest,
    PostDepartmentsRequestBody,
    PostDepartmentsRequestBodyTypedDict,
    PostDepartmentsRequestTypedDict,
)
from .post_employee_ytd_benefit_amounts_from_different_company import (
    PostEmployeeYtdBenefitAmountsFromDifferentCompany,
    PostEmployeeYtdBenefitAmountsFromDifferentCompanyTypedDict,
)
from .post_employee_ytd_benefit_amounts_from_different_companyop import (
    PostEmployeeYtdBenefitAmountsFromDifferentCompanyRequest,
    PostEmployeeYtdBenefitAmountsFromDifferentCompanyRequestTypedDict,
)
from .post_partner_managed_companies_company_uuid_accept_terms_of_serviceop import (
    PostPartnerManagedCompaniesCompanyUUIDAcceptTermsOfServiceRequest,
    PostPartnerManagedCompaniesCompanyUUIDAcceptTermsOfServiceRequestBody,
    PostPartnerManagedCompaniesCompanyUUIDAcceptTermsOfServiceRequestBodyTypedDict,
    PostPartnerManagedCompaniesCompanyUUIDAcceptTermsOfServiceRequestTypedDict,
    PostPartnerManagedCompaniesCompanyUUIDAcceptTermsOfServiceResponseBody,
    PostPartnerManagedCompaniesCompanyUUIDAcceptTermsOfServiceResponseBodyTypedDict,
)
from .post_partner_managed_companies_company_uuid_retrieve_terms_of_serviceop import (
    PostPartnerManagedCompaniesCompanyUUIDRetrieveTermsOfServiceRequest,
    PostPartnerManagedCompaniesCompanyUUIDRetrieveTermsOfServiceRequestBody,
    PostPartnerManagedCompaniesCompanyUUIDRetrieveTermsOfServiceRequestBodyTypedDict,
    PostPartnerManagedCompaniesCompanyUUIDRetrieveTermsOfServiceRequestTypedDict,
    PostPartnerManagedCompaniesCompanyUUIDRetrieveTermsOfServiceResponseBody,
    PostPartnerManagedCompaniesCompanyUUIDRetrieveTermsOfServiceResponseBodyTypedDict,
)
from .post_payrolls_gross_up_payroll_uuidop import (
    PostPayrollsGrossUpPayrollUUIDRequest,
    PostPayrollsGrossUpPayrollUUIDRequestBody,
    PostPayrollsGrossUpPayrollUUIDRequestBodyTypedDict,
    PostPayrollsGrossUpPayrollUUIDRequestTypedDict,
    PostPayrollsGrossUpPayrollUUIDResponseBody,
    PostPayrollsGrossUpPayrollUUIDResponseBodyUnion,
)
from .post_v1_companies_attachmentop import (
    PostV1CompaniesAttachmentCategory,
    PostV1CompaniesAttachmentDocument,
    PostV1CompaniesAttachmentDocumentTypedDict,
    PostV1CompaniesAttachmentRequest,
    PostV1CompaniesAttachmentRequestBody,
    PostV1CompaniesAttachmentRequestBodyTypedDict,
    PostV1CompaniesAttachmentRequestTypedDict,
)
from .post_v1_companies_company_id_adminsop import (
    PostV1CompaniesCompanyIDAdminsRequest,
    PostV1CompaniesCompanyIDAdminsRequestBody,
    PostV1CompaniesCompanyIDAdminsRequestBodyTypedDict,
    PostV1CompaniesCompanyIDAdminsRequestTypedDict,
)
from .post_v1_companies_company_id_bank_accountsop import (
    PostV1CompaniesCompanyIDBankAccountsAccountType,
    PostV1CompaniesCompanyIDBankAccountsRequest,
    PostV1CompaniesCompanyIDBankAccountsRequestBody,
    PostV1CompaniesCompanyIDBankAccountsRequestBodyTypedDict,
    PostV1CompaniesCompanyIDBankAccountsRequestTypedDict,
)
from .post_v1_companies_company_id_company_benefitsop import (
    PostV1CompaniesCompanyIDCompanyBenefitsRequest,
    PostV1CompaniesCompanyIDCompanyBenefitsRequestBody,
    PostV1CompaniesCompanyIDCompanyBenefitsRequestBodyTypedDict,
    PostV1CompaniesCompanyIDCompanyBenefitsRequestTypedDict,
)
from .post_v1_companies_company_id_contractor_payment_groups_previewop import (
    PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewContractorPayments,
    PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewContractorPaymentsTypedDict,
    PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewPaymentMethod,
    PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewRequest,
    PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewRequestBody,
    PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewRequestBodyTypedDict,
    PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewRequestTypedDict,
)
from .post_v1_companies_company_id_contractor_payment_groupsop import (
    PostV1CompaniesCompanyIDContractorPaymentGroupsContractorPayments,
    PostV1CompaniesCompanyIDContractorPaymentGroupsContractorPaymentsTypedDict,
    PostV1CompaniesCompanyIDContractorPaymentGroupsPaymentMethod,
    PostV1CompaniesCompanyIDContractorPaymentGroupsRequest,
    PostV1CompaniesCompanyIDContractorPaymentGroupsRequestBody,
    PostV1CompaniesCompanyIDContractorPaymentGroupsRequestBodyTypedDict,
    PostV1CompaniesCompanyIDContractorPaymentGroupsRequestTypedDict,
)
from .post_v1_companies_company_id_contractor_paymentsop import (
    PostV1CompaniesCompanyIDContractorPaymentsPaymentMethod,
    PostV1CompaniesCompanyIDContractorPaymentsRequest,
    PostV1CompaniesCompanyIDContractorPaymentsRequestBody,
    PostV1CompaniesCompanyIDContractorPaymentsRequestBodyTypedDict,
    PostV1CompaniesCompanyIDContractorPaymentsRequestTypedDict,
)
from .post_v1_companies_company_id_earning_typesop import (
    PostV1CompaniesCompanyIDEarningTypesRequest,
    PostV1CompaniesCompanyIDEarningTypesRequestBody,
    PostV1CompaniesCompanyIDEarningTypesRequestBodyTypedDict,
    PostV1CompaniesCompanyIDEarningTypesRequestTypedDict,
)
from .post_v1_companies_company_id_locationsop import (
    PostV1CompaniesCompanyIDLocationsRequest,
    PostV1CompaniesCompanyIDLocationsRequestBody,
    PostV1CompaniesCompanyIDLocationsRequestBodyTypedDict,
    PostV1CompaniesCompanyIDLocationsRequestTypedDict,
)
from .post_v1_companies_company_id_pay_schedules_assignment_previewop import (
    PostV1CompaniesCompanyIDPaySchedulesAssignmentPreviewRequest,
    PostV1CompaniesCompanyIDPaySchedulesAssignmentPreviewRequestTypedDict,
)
from .post_v1_companies_company_id_pay_schedules_assignop import (
    PostV1CompaniesCompanyIDPaySchedulesAssignRequest,
    PostV1CompaniesCompanyIDPaySchedulesAssignRequestTypedDict,
)
from .post_v1_companies_company_id_pay_schedulesop import (
    Frequency,
    PostV1CompaniesCompanyIDPaySchedulesRequest,
    PostV1CompaniesCompanyIDPaySchedulesRequestBody,
    PostV1CompaniesCompanyIDPaySchedulesRequestBodyTypedDict,
    PostV1CompaniesCompanyIDPaySchedulesRequestTypedDict,
)
from .post_v1_companies_company_id_payrollsop import (
    OffCycleReason,
    PostV1CompaniesCompanyIDPayrollsRequest,
    PostV1CompaniesCompanyIDPayrollsRequestBody,
    PostV1CompaniesCompanyIDPayrollsRequestBodyTypedDict,
    PostV1CompaniesCompanyIDPayrollsRequestTypedDict,
    WithholdingPayPeriod,
)
from .post_v1_companies_company_uuid_contractorsop import (
    PostV1CompaniesCompanyUUIDContractorsRequest,
    PostV1CompaniesCompanyUUIDContractorsRequestBody,
    PostV1CompaniesCompanyUUIDContractorsRequestBodyTypedDict,
    PostV1CompaniesCompanyUUIDContractorsRequestTypedDict,
    PostV1CompaniesCompanyUUIDContractorsType,
    PostV1CompaniesCompanyUUIDContractorsWageType,
)
from .post_v1_companies_company_uuid_signatories_inviteop import (
    PostV1CompaniesCompanyUUIDSignatoriesInviteRequest,
    PostV1CompaniesCompanyUUIDSignatoriesInviteRequestBody,
    PostV1CompaniesCompanyUUIDSignatoriesInviteRequestBodyTypedDict,
    PostV1CompaniesCompanyUUIDSignatoriesInviteRequestTypedDict,
)
from .post_v1_company_flowsop import (
    PostV1CompanyFlowsEntityType,
    PostV1CompanyFlowsRequest,
    PostV1CompanyFlowsRequestBody,
    PostV1CompanyFlowsRequestBodyTypedDict,
    PostV1CompanyFlowsRequestTypedDict,
)
from .post_v1_company_signatoriesop import (
    PostV1CompanySignatoriesHomeAddress,
    PostV1CompanySignatoriesHomeAddressTypedDict,
    PostV1CompanySignatoriesRequest,
    PostV1CompanySignatoriesRequestBody,
    PostV1CompanySignatoriesRequestBodyTypedDict,
    PostV1CompanySignatoriesRequestTypedDict,
)
from .post_v1_compensations_compensation_idop import (
    PostV1CompensationsCompensationIDMinimumWages,
    PostV1CompensationsCompensationIDMinimumWagesTypedDict,
    PostV1CompensationsCompensationIDPaymentUnit,
    PostV1CompensationsCompensationIDRequest,
    PostV1CompensationsCompensationIDRequestBody,
    PostV1CompensationsCompensationIDRequestBodyTypedDict,
    PostV1CompensationsCompensationIDRequestTypedDict,
)
from .post_v1_contractors_contractor_uuid_bank_accountsop import (
    PostV1ContractorsContractorUUIDBankAccountsAccountType,
    PostV1ContractorsContractorUUIDBankAccountsRequest,
    PostV1ContractorsContractorUUIDBankAccountsRequestBody,
    PostV1ContractorsContractorUUIDBankAccountsRequestBodyTypedDict,
    PostV1ContractorsContractorUUIDBankAccountsRequestTypedDict,
)
from .post_v1_employees_employee_id_bank_accountsop import (
    PostV1EmployeesEmployeeIDBankAccountsAccountType,
    PostV1EmployeesEmployeeIDBankAccountsRequest,
    PostV1EmployeesEmployeeIDBankAccountsRequestBody,
    PostV1EmployeesEmployeeIDBankAccountsRequestBodyTypedDict,
    PostV1EmployeesEmployeeIDBankAccountsRequestTypedDict,
)
from .post_v1_employees_employee_id_employee_benefitsop import (
    PostV1EmployeesEmployeeIDEmployeeBenefitsContribution,
    PostV1EmployeesEmployeeIDEmployeeBenefitsContributionTypedDict,
    PostV1EmployeesEmployeeIDEmployeeBenefitsDeductionReducesTaxableIncome,
    PostV1EmployeesEmployeeIDEmployeeBenefitsLimitOption,
    PostV1EmployeesEmployeeIDEmployeeBenefitsRequest,
    PostV1EmployeesEmployeeIDEmployeeBenefitsRequestBody,
    PostV1EmployeesEmployeeIDEmployeeBenefitsRequestBodyTypedDict,
    PostV1EmployeesEmployeeIDEmployeeBenefitsRequestTypedDict,
    PostV1EmployeesEmployeeIDEmployeeBenefitsType,
    PostV1EmployeesEmployeeIDEmployeeBenefitsValue,
    PostV1EmployeesEmployeeIDEmployeeBenefitsValue2,
    PostV1EmployeesEmployeeIDEmployeeBenefitsValue2TypedDict,
    PostV1EmployeesEmployeeIDEmployeeBenefitsValueTypedDict,
)
from .post_v1_employees_employee_id_garnishmentsop import (
    PostV1EmployeesEmployeeIDGarnishmentsGarnishmentType,
    PostV1EmployeesEmployeeIDGarnishmentsRequest,
    PostV1EmployeesEmployeeIDGarnishmentsRequestBody,
    PostV1EmployeesEmployeeIDGarnishmentsRequestBodyTypedDict,
    PostV1EmployeesEmployeeIDGarnishmentsRequestTypedDict,
)
from .post_v1_employees_employee_id_home_addressesop import (
    PostV1EmployeesEmployeeIDHomeAddressesRequest,
    PostV1EmployeesEmployeeIDHomeAddressesRequestBody,
    PostV1EmployeesEmployeeIDHomeAddressesRequestBodyTypedDict,
    PostV1EmployeesEmployeeIDHomeAddressesRequestTypedDict,
)
from .post_v1_employees_employee_id_rehireop import (
    PostV1EmployeesEmployeeIDRehireRequest,
    PostV1EmployeesEmployeeIDRehireRequestTypedDict,
)
from .post_v1_employees_employee_id_terminationsop import (
    PostV1EmployeesEmployeeIDTerminationsRequest,
    PostV1EmployeesEmployeeIDTerminationsRequestBody,
    PostV1EmployeesEmployeeIDTerminationsRequestBodyTypedDict,
    PostV1EmployeesEmployeeIDTerminationsRequestTypedDict,
)
from .post_v1_employees_employee_id_work_addressesop import (
    PostV1EmployeesEmployeeIDWorkAddressesRequest,
    PostV1EmployeesEmployeeIDWorkAddressesRequestBody,
    PostV1EmployeesEmployeeIDWorkAddressesRequestBodyTypedDict,
    PostV1EmployeesEmployeeIDWorkAddressesRequestTypedDict,
)
from .post_v1_employeesop import (
    PostV1EmployeesRequest,
    PostV1EmployeesRequestBody,
    PostV1EmployeesRequestBodyTypedDict,
    PostV1EmployeesRequestTypedDict,
)
from .post_v1_external_payrollop import (
    PostV1ExternalPayrollRequest,
    PostV1ExternalPayrollRequestBody,
    PostV1ExternalPayrollRequestBodyTypedDict,
    PostV1ExternalPayrollRequestTypedDict,
)
from .post_v1_historical_employeesop import (
    PostV1HistoricalEmployeesRequest,
    PostV1HistoricalEmployeesRequestTypedDict,
)
from .post_v1_jobs_job_idop import (
    PostV1JobsJobIDRequest,
    PostV1JobsJobIDRequestBody,
    PostV1JobsJobIDRequestBodyTypedDict,
    PostV1JobsJobIDRequestTypedDict,
)
from .post_v1_partner_managed_companiesop import (
    PostV1PartnerManagedCompaniesCompany,
    PostV1PartnerManagedCompaniesCompanyTypedDict,
    PostV1PartnerManagedCompaniesRequest,
    PostV1PartnerManagedCompaniesRequestBody,
    PostV1PartnerManagedCompaniesRequestBodyTypedDict,
    PostV1PartnerManagedCompaniesRequestTypedDict,
    PostV1PartnerManagedCompaniesResponseBody,
    PostV1PartnerManagedCompaniesResponseBodyTypedDict,
    PostV1PartnerManagedCompaniesSecurity,
    PostV1PartnerManagedCompaniesSecurityTypedDict,
    User,
    UserTypedDict,
)
from .post_v1_payrolls_payroll_id_calculate_accruing_time_off_hoursop import (
    PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequest,
    PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestBody,
    PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestBodyTypedDict,
    PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestTypedDict,
)
from .post_v1_payrolls_payroll_uuid_generated_documents_printable_payroll_checksop import (
    PostV1PayrollsPayrollUUIDGeneratedDocumentsPrintablePayrollChecksRequest,
    PostV1PayrollsPayrollUUIDGeneratedDocumentsPrintablePayrollChecksRequestBody,
    PostV1PayrollsPayrollUUIDGeneratedDocumentsPrintablePayrollChecksRequestBodyTypedDict,
    PostV1PayrollsPayrollUUIDGeneratedDocumentsPrintablePayrollChecksRequestTypedDict,
    PrintingFormat,
)
from .post_v1_plaid_processor_tokenop import (
    OwnerType,
    PostV1PlaidProcessorTokenRequest,
    PostV1PlaidProcessorTokenRequestBody,
    PostV1PlaidProcessorTokenRequestBodyTypedDict,
    PostV1PlaidProcessorTokenRequestTypedDict,
    PostV1PlaidProcessorTokenResponseBody,
    PostV1PlaidProcessorTokenResponseBodyTypedDict,
)
from .post_v1_sandbox_generate_1099op import (
    PostV1SandboxGenerate1099Request,
    PostV1SandboxGenerate1099RequestBody,
    PostV1SandboxGenerate1099RequestBodyTypedDict,
    PostV1SandboxGenerate1099RequestTypedDict,
)
from .post_v1_sandbox_generate_w2op import (
    PostV1SandboxGenerateW2Form,
    PostV1SandboxGenerateW2FormTypedDict,
    PostV1SandboxGenerateW2Request,
    PostV1SandboxGenerateW2RequestBody,
    PostV1SandboxGenerateW2RequestBodyTypedDict,
    PostV1SandboxGenerateW2RequestTypedDict,
)
from .post_v1_webhook_subscriptionop import (
    PostV1WebhookSubscriptionRequest,
    PostV1WebhookSubscriptionRequestBody,
    PostV1WebhookSubscriptionRequestBodyTypedDict,
    PostV1WebhookSubscriptionRequestTypedDict,
    PostV1WebhookSubscriptionSecurity,
    PostV1WebhookSubscriptionSecurityTypedDict,
    PostV1WebhookSubscriptionSubscriptionTypes,
)
from .put_add_people_to_departmentop import (
    PutAddPeopleToDepartmentContractors,
    PutAddPeopleToDepartmentContractorsTypedDict,
    PutAddPeopleToDepartmentEmployees,
    PutAddPeopleToDepartmentEmployeesTypedDict,
    PutAddPeopleToDepartmentRequest,
    PutAddPeopleToDepartmentRequestBody,
    PutAddPeopleToDepartmentRequestBodyTypedDict,
    PutAddPeopleToDepartmentRequestTypedDict,
)
from .put_api_v1_companies_company_id_payrolls_payroll_id_cancelop import (
    PutAPIV1CompaniesCompanyIDPayrollsPayrollIDCancelRequest,
    PutAPIV1CompaniesCompanyIDPayrollsPayrollIDCancelRequestTypedDict,
)
from .put_companies_company_uuid_holiday_pay_policy_addop import (
    PutCompaniesCompanyUUIDHolidayPayPolicyAddEmployees,
    PutCompaniesCompanyUUIDHolidayPayPolicyAddEmployeesTypedDict,
    PutCompaniesCompanyUUIDHolidayPayPolicyAddRequest,
    PutCompaniesCompanyUUIDHolidayPayPolicyAddRequestBody,
    PutCompaniesCompanyUUIDHolidayPayPolicyAddRequestBodyTypedDict,
    PutCompaniesCompanyUUIDHolidayPayPolicyAddRequestTypedDict,
)
from .put_companies_company_uuid_holiday_pay_policy_removeop import (
    PutCompaniesCompanyUUIDHolidayPayPolicyRemoveEmployees,
    PutCompaniesCompanyUUIDHolidayPayPolicyRemoveEmployeesTypedDict,
    PutCompaniesCompanyUUIDHolidayPayPolicyRemoveRequest,
    PutCompaniesCompanyUUIDHolidayPayPolicyRemoveRequestBody,
    PutCompaniesCompanyUUIDHolidayPayPolicyRemoveRequestBodyTypedDict,
    PutCompaniesCompanyUUIDHolidayPayPolicyRemoveRequestTypedDict,
)
from .put_companies_company_uuid_holiday_pay_policyop import (
    PutCompaniesCompanyUUIDHolidayPayPolicyChristmasDay,
    PutCompaniesCompanyUUIDHolidayPayPolicyChristmasDayTypedDict,
    PutCompaniesCompanyUUIDHolidayPayPolicyColumbusDay,
    PutCompaniesCompanyUUIDHolidayPayPolicyColumbusDayTypedDict,
    PutCompaniesCompanyUUIDHolidayPayPolicyFederalHolidays,
    PutCompaniesCompanyUUIDHolidayPayPolicyFederalHolidaysTypedDict,
    PutCompaniesCompanyUUIDHolidayPayPolicyIndependenceDay,
    PutCompaniesCompanyUUIDHolidayPayPolicyIndependenceDayTypedDict,
    PutCompaniesCompanyUUIDHolidayPayPolicyJuneteenth,
    PutCompaniesCompanyUUIDHolidayPayPolicyJuneteenthTypedDict,
    PutCompaniesCompanyUUIDHolidayPayPolicyLaborDay,
    PutCompaniesCompanyUUIDHolidayPayPolicyLaborDayTypedDict,
    PutCompaniesCompanyUUIDHolidayPayPolicyMemorialDay,
    PutCompaniesCompanyUUIDHolidayPayPolicyMemorialDayTypedDict,
    PutCompaniesCompanyUUIDHolidayPayPolicyMlkDay,
    PutCompaniesCompanyUUIDHolidayPayPolicyMlkDayTypedDict,
    PutCompaniesCompanyUUIDHolidayPayPolicyNewYearsDay,
    PutCompaniesCompanyUUIDHolidayPayPolicyNewYearsDayTypedDict,
    PutCompaniesCompanyUUIDHolidayPayPolicyPresidentsDay,
    PutCompaniesCompanyUUIDHolidayPayPolicyPresidentsDayTypedDict,
    PutCompaniesCompanyUUIDHolidayPayPolicyRequest,
    PutCompaniesCompanyUUIDHolidayPayPolicyRequestBody,
    PutCompaniesCompanyUUIDHolidayPayPolicyRequestBodyTypedDict,
    PutCompaniesCompanyUUIDHolidayPayPolicyRequestTypedDict,
    PutCompaniesCompanyUUIDHolidayPayPolicyThanksgiving,
    PutCompaniesCompanyUUIDHolidayPayPolicyThanksgivingTypedDict,
    PutCompaniesCompanyUUIDHolidayPayPolicyVeteransDay,
    PutCompaniesCompanyUUIDHolidayPayPolicyVeteransDayTypedDict,
)
from .put_departmentsop import (
    PutDepartmentsRequest,
    PutDepartmentsRequestBody,
    PutDepartmentsRequestBodyTypedDict,
    PutDepartmentsRequestTypedDict,
)
from .put_remove_people_from_departmentop import (
    PutRemovePeopleFromDepartmentContractors,
    PutRemovePeopleFromDepartmentContractorsTypedDict,
    PutRemovePeopleFromDepartmentEmployees,
    PutRemovePeopleFromDepartmentEmployeesTypedDict,
    PutRemovePeopleFromDepartmentRequest,
    PutRemovePeopleFromDepartmentRequestBody,
    PutRemovePeopleFromDepartmentRequestBodyTypedDict,
    PutRemovePeopleFromDepartmentRequestTypedDict,
)
from .put_time_off_policies_time_off_policy_uuidop import (
    AccrualMethod,
    PutTimeOffPoliciesTimeOffPolicyUUIDRequest,
    PutTimeOffPoliciesTimeOffPolicyUUIDRequestBody,
    PutTimeOffPoliciesTimeOffPolicyUUIDRequestBodyTypedDict,
    PutTimeOffPoliciesTimeOffPolicyUUIDRequestTypedDict,
)
from .put_v1_companies_company_id_bank_accounts_verifyop import (
    PutV1CompaniesCompanyIDBankAccountsVerifyRequest,
    PutV1CompaniesCompanyIDBankAccountsVerifyRequestBody,
    PutV1CompaniesCompanyIDBankAccountsVerifyRequestBodyTypedDict,
    PutV1CompaniesCompanyIDBankAccountsVerifyRequestTypedDict,
)
from .put_v1_companies_company_id_earning_types_earning_type_uuidop import (
    PutV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequest,
    PutV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequestBody,
    PutV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequestBodyTypedDict,
    PutV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequestTypedDict,
)
from .put_v1_companies_company_id_federal_tax_detailsop import (
    FilingForm,
    PutV1CompaniesCompanyIDFederalTaxDetailsRequest,
    PutV1CompaniesCompanyIDFederalTaxDetailsRequestBody,
    PutV1CompaniesCompanyIDFederalTaxDetailsRequestBodyTypedDict,
    PutV1CompaniesCompanyIDFederalTaxDetailsRequestTypedDict,
    TaxPayerType,
)
from .put_v1_companies_company_id_pay_schedules_pay_schedule_idop import (
    PutV1CompaniesCompanyIDPaySchedulesPayScheduleIDFrequency,
    PutV1CompaniesCompanyIDPaySchedulesPayScheduleIDRequest,
    PutV1CompaniesCompanyIDPaySchedulesPayScheduleIDRequestBody,
    PutV1CompaniesCompanyIDPaySchedulesPayScheduleIDRequestBodyTypedDict,
    PutV1CompaniesCompanyIDPaySchedulesPayScheduleIDRequestTypedDict,
)
from .put_v1_companies_company_id_payrolls_payroll_id_calculateop import (
    PutV1CompaniesCompanyIDPayrollsPayrollIDCalculateRequest,
    PutV1CompaniesCompanyIDPayrollsPayrollIDCalculateRequestTypedDict,
    PutV1CompaniesCompanyIDPayrollsPayrollIDCalculateResponseBody,
    PutV1CompaniesCompanyIDPayrollsPayrollIDCalculateResponseBodyUnion,
)
from .put_v1_companies_company_id_payrolls_payroll_id_prepareop import (
    PutV1CompaniesCompanyIDPayrollsPayrollIDPrepareRequest,
    PutV1CompaniesCompanyIDPayrollsPayrollIDPrepareRequestTypedDict,
)
from .put_v1_companies_company_id_payrolls_payroll_id_submitop import (
    PutV1CompaniesCompanyIDPayrollsPayrollIDSubmitRequest,
    PutV1CompaniesCompanyIDPayrollsPayrollIDSubmitRequestBody,
    PutV1CompaniesCompanyIDPayrollsPayrollIDSubmitRequestBodyTypedDict,
    PutV1CompaniesCompanyIDPayrollsPayrollIDSubmitRequestTypedDict,
    PutV1CompaniesCompanyIDPayrollsPayrollIDSubmitResponseBody,
    PutV1CompaniesCompanyIDPayrollsPayrollIDSubmitResponseBodyUnion,
    SubmissionBlockers,
    SubmissionBlockersTypedDict,
)
from .put_v1_companies_company_id_payrollsop import (
    PutV1CompaniesCompanyIDPayrollsEmployeeCompensations,
    PutV1CompaniesCompanyIDPayrollsEmployeeCompensationsTypedDict,
    PutV1CompaniesCompanyIDPayrollsFixedCompensations,
    PutV1CompaniesCompanyIDPayrollsFixedCompensationsTypedDict,
    PutV1CompaniesCompanyIDPayrollsHourlyCompensations,
    PutV1CompaniesCompanyIDPayrollsHourlyCompensationsTypedDict,
    PutV1CompaniesCompanyIDPayrollsPaidTimeOff,
    PutV1CompaniesCompanyIDPayrollsPaidTimeOffTypedDict,
    PutV1CompaniesCompanyIDPayrollsPaymentMethod,
    PutV1CompaniesCompanyIDPayrollsRequest,
    PutV1CompaniesCompanyIDPayrollsRequestBody,
    PutV1CompaniesCompanyIDPayrollsRequestBodyTypedDict,
    PutV1CompaniesCompanyIDPayrollsRequestTypedDict,
)
from .put_v1_companies_company_uuid_signatories_signatory_uuidop import (
    PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDHomeAddress,
    PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDHomeAddressTypedDict,
    PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDRequest,
    PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDRequestBody,
    PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDRequestBodyTypedDict,
    PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDRequestTypedDict,
)
from .put_v1_companies_company_uuid_tax_requirements_stateop import (
    PutV1CompaniesCompanyUUIDTaxRequirementsStateRequest,
    PutV1CompaniesCompanyUUIDTaxRequirementsStateRequestBody,
    PutV1CompaniesCompanyUUIDTaxRequirementsStateRequestBodyTypedDict,
    PutV1CompaniesCompanyUUIDTaxRequirementsStateRequestTypedDict,
    PutV1CompaniesCompanyUUIDTaxRequirementsStateRequirements,
    PutV1CompaniesCompanyUUIDTaxRequirementsStateRequirementsTypedDict,
    RequirementSets,
    RequirementSetsTypedDict,
)
from .put_v1_companiesop import (
    PutV1CompaniesRequest,
    PutV1CompaniesRequestBody,
    PutV1CompaniesRequestBodyTypedDict,
    PutV1CompaniesRequestTypedDict,
)
from .put_v1_company_benefits_company_benefit_id_employee_benefitsop import (
    PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequest,
    PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestBody,
    PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestBodyTypedDict,
    PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestTypedDict,
)
from .put_v1_company_benefits_company_benefit_idop import (
    PutV1CompanyBenefitsCompanyBenefitIDRequest,
    PutV1CompanyBenefitsCompanyBenefitIDRequestBody,
    PutV1CompanyBenefitsCompanyBenefitIDRequestBodyTypedDict,
    PutV1CompanyBenefitsCompanyBenefitIDRequestTypedDict,
)
from .put_v1_company_form_signop import (
    PutV1CompanyFormSignRequest,
    PutV1CompanyFormSignRequestBody,
    PutV1CompanyFormSignRequestBodyTypedDict,
    PutV1CompanyFormSignRequestTypedDict,
)
from .put_v1_company_industryop import (
    PutV1CompanyIndustryRequest,
    PutV1CompanyIndustryRequestBody,
    PutV1CompanyIndustryRequestBodyTypedDict,
    PutV1CompanyIndustryRequestTypedDict,
)
from .put_v1_company_payment_configsop import (
    PutV1CompanyPaymentConfigsRequest,
    PutV1CompanyPaymentConfigsRequestBody,
    PutV1CompanyPaymentConfigsRequestBodyTypedDict,
    PutV1CompanyPaymentConfigsRequestTypedDict,
)
from .put_v1_compensations_compensation_idop import (
    PutV1CompensationsCompensationIDMinimumWages,
    PutV1CompensationsCompensationIDMinimumWagesTypedDict,
    PutV1CompensationsCompensationIDPaymentUnit,
    PutV1CompensationsCompensationIDRequest,
    PutV1CompensationsCompensationIDRequestBody,
    PutV1CompensationsCompensationIDRequestBodyTypedDict,
    PutV1CompensationsCompensationIDRequestTypedDict,
)
from .put_v1_contractor_document_signop import (
    PutV1ContractorDocumentSignFields,
    PutV1ContractorDocumentSignFieldsTypedDict,
    PutV1ContractorDocumentSignRequest,
    PutV1ContractorDocumentSignRequestBody,
    PutV1ContractorDocumentSignRequestBodyTypedDict,
    PutV1ContractorDocumentSignRequestTypedDict,
)
from .put_v1_contractor_payment_groups_contractor_payment_group_id_fundop import (
    PutV1ContractorPaymentGroupsContractorPaymentGroupIDFundRequest,
    PutV1ContractorPaymentGroupsContractorPaymentGroupIDFundRequestTypedDict,
)
from .put_v1_contractors_contractor_id_payment_methodop import (
    PutV1ContractorsContractorIDPaymentMethodRequest,
    PutV1ContractorsContractorIDPaymentMethodRequestBody,
    PutV1ContractorsContractorIDPaymentMethodRequestBodyTypedDict,
    PutV1ContractorsContractorIDPaymentMethodRequestTypedDict,
    PutV1ContractorsContractorIDPaymentMethodType,
)
from .put_v1_contractors_contractor_uuid_addressop import (
    PutV1ContractorsContractorUUIDAddressRequest,
    PutV1ContractorsContractorUUIDAddressRequestBody,
    PutV1ContractorsContractorUUIDAddressRequestBodyTypedDict,
    PutV1ContractorsContractorUUIDAddressRequestTypedDict,
)
from .put_v1_contractors_contractor_uuid_onboarding_statusop import (
    PutV1ContractorsContractorUUIDOnboardingStatusOnboardingStatus,
    PutV1ContractorsContractorUUIDOnboardingStatusRequest,
    PutV1ContractorsContractorUUIDOnboardingStatusRequestBody,
    PutV1ContractorsContractorUUIDOnboardingStatusRequestBodyTypedDict,
    PutV1ContractorsContractorUUIDOnboardingStatusRequestTypedDict,
)
from .put_v1_contractors_contractor_uuidop import (
    PutV1ContractorsContractorUUIDRequest,
    PutV1ContractorsContractorUUIDRequestBody,
    PutV1ContractorsContractorUUIDRequestBodyTypedDict,
    PutV1ContractorsContractorUUIDRequestTypedDict,
    PutV1ContractorsContractorUUIDType,
    PutV1ContractorsContractorUUIDWageType,
)
from .put_v1_employee_benefits_employee_benefit_idop import (
    PutV1EmployeeBenefitsEmployeeBenefitIDContribution,
    PutV1EmployeeBenefitsEmployeeBenefitIDContributionTypedDict,
    PutV1EmployeeBenefitsEmployeeBenefitIDDeductionReducesTaxableIncome,
    PutV1EmployeeBenefitsEmployeeBenefitIDLimitOption,
    PutV1EmployeeBenefitsEmployeeBenefitIDRequest,
    PutV1EmployeeBenefitsEmployeeBenefitIDRequestBody,
    PutV1EmployeeBenefitsEmployeeBenefitIDRequestBodyTypedDict,
    PutV1EmployeeBenefitsEmployeeBenefitIDRequestTypedDict,
    PutV1EmployeeBenefitsEmployeeBenefitIDType,
    PutV1EmployeeBenefitsEmployeeBenefitIDValue,
    PutV1EmployeeBenefitsEmployeeBenefitIDValue2,
    PutV1EmployeeBenefitsEmployeeBenefitIDValue2TypedDict,
    PutV1EmployeeBenefitsEmployeeBenefitIDValueTypedDict,
)
from .put_v1_employee_form_signop import (
    PutV1EmployeeFormSignRequest,
    PutV1EmployeeFormSignRequestBody,
    PutV1EmployeeFormSignRequestBodyTypedDict,
    PutV1EmployeeFormSignRequestTypedDict,
)
from .put_v1_employees_employee_id_bank_accountsop import (
    PutV1EmployeesEmployeeIDBankAccountsAccountType,
    PutV1EmployeesEmployeeIDBankAccountsRequest,
    PutV1EmployeesEmployeeIDBankAccountsRequestBody,
    PutV1EmployeesEmployeeIDBankAccountsRequestBodyTypedDict,
    PutV1EmployeesEmployeeIDBankAccountsRequestTypedDict,
)
from .put_v1_employees_employee_id_federal_taxesop import (
    PutV1EmployeesEmployeeIDFederalTaxesRequest,
    PutV1EmployeesEmployeeIDFederalTaxesRequestBody,
    PutV1EmployeesEmployeeIDFederalTaxesRequestBodyTypedDict,
    PutV1EmployeesEmployeeIDFederalTaxesRequestTypedDict,
)
from .put_v1_employees_employee_id_i9_authorization_documentsop import (
    Documents,
    DocumentsTypedDict,
    PutV1EmployeesEmployeeIDI9AuthorizationDocumentsRequest,
    PutV1EmployeesEmployeeIDI9AuthorizationDocumentsRequestBody,
    PutV1EmployeesEmployeeIDI9AuthorizationDocumentsRequestBodyTypedDict,
    PutV1EmployeesEmployeeIDI9AuthorizationDocumentsRequestTypedDict,
)
from .put_v1_employees_employee_id_i9_authorization_employer_signop import (
    PutV1EmployeesEmployeeIDI9AuthorizationEmployerSignRequest,
    PutV1EmployeesEmployeeIDI9AuthorizationEmployerSignRequestBody,
    PutV1EmployeesEmployeeIDI9AuthorizationEmployerSignRequestBodyTypedDict,
    PutV1EmployeesEmployeeIDI9AuthorizationEmployerSignRequestTypedDict,
)
from .put_v1_employees_employee_id_i9_authorizationop import (
    PutV1EmployeesEmployeeIDI9AuthorizationAuthorizationStatus,
    PutV1EmployeesEmployeeIDI9AuthorizationDocumentType,
    PutV1EmployeesEmployeeIDI9AuthorizationRequest,
    PutV1EmployeesEmployeeIDI9AuthorizationRequestBody,
    PutV1EmployeesEmployeeIDI9AuthorizationRequestBodyTypedDict,
    PutV1EmployeesEmployeeIDI9AuthorizationRequestTypedDict,
)
from .put_v1_employees_employee_id_onboarding_documents_configop import (
    PutV1EmployeesEmployeeIDOnboardingDocumentsConfigRequest,
    PutV1EmployeesEmployeeIDOnboardingDocumentsConfigRequestBody,
    PutV1EmployeesEmployeeIDOnboardingDocumentsConfigRequestBodyTypedDict,
    PutV1EmployeesEmployeeIDOnboardingDocumentsConfigRequestTypedDict,
)
from .put_v1_employees_employee_id_onboarding_statusop import (
    PutV1EmployeesEmployeeIDOnboardingStatusRequest,
    PutV1EmployeesEmployeeIDOnboardingStatusRequestBody,
    PutV1EmployeesEmployeeIDOnboardingStatusRequestBodyTypedDict,
    PutV1EmployeesEmployeeIDOnboardingStatusRequestTypedDict,
)
from .put_v1_employees_employee_id_payment_methodop import (
    PutV1EmployeesEmployeeIDPaymentMethodRequest,
    PutV1EmployeesEmployeeIDPaymentMethodRequestBody,
    PutV1EmployeesEmployeeIDPaymentMethodRequestBodyTypedDict,
    PutV1EmployeesEmployeeIDPaymentMethodRequestTypedDict,
    PutV1EmployeesEmployeeIDPaymentMethodSplitBy,
    PutV1EmployeesEmployeeIDPaymentMethodType,
    Splits,
    SplitsTypedDict,
)
from .put_v1_employees_employee_id_rehireop import (
    PutV1EmployeesEmployeeIDRehireEmploymentStatus,
    PutV1EmployeesEmployeeIDRehireRequest,
    PutV1EmployeesEmployeeIDRehireRequestBody,
    PutV1EmployeesEmployeeIDRehireRequestBodyTypedDict,
    PutV1EmployeesEmployeeIDRehireRequestTypedDict,
)
from .put_v1_employees_employee_id_state_taxesop import (
    Answers,
    AnswersTypedDict,
    PutV1EmployeesEmployeeIDStateTaxesRequest,
    PutV1EmployeesEmployeeIDStateTaxesRequestBody,
    PutV1EmployeesEmployeeIDStateTaxesRequestBodyTypedDict,
    PutV1EmployeesEmployeeIDStateTaxesRequestTypedDict,
    Questions,
    QuestionsTypedDict,
    States,
    StatesTypedDict,
)
from .put_v1_employeesop import (
    PutV1EmployeesRequest,
    PutV1EmployeesRequestBody,
    PutV1EmployeesRequestBodyTypedDict,
    PutV1EmployeesRequestTypedDict,
)
from .put_v1_external_payrollop import (
    PutV1ExternalPayrollBenefits,
    PutV1ExternalPayrollBenefitsTypedDict,
    PutV1ExternalPayrollEarningType,
    PutV1ExternalPayrollEarnings,
    PutV1ExternalPayrollEarningsTypedDict,
    PutV1ExternalPayrollExternalPayrollItems,
    PutV1ExternalPayrollExternalPayrollItemsTypedDict,
    PutV1ExternalPayrollRequest,
    PutV1ExternalPayrollRequestBody,
    PutV1ExternalPayrollRequestBodyTypedDict,
    PutV1ExternalPayrollRequestTypedDict,
    PutV1ExternalPayrollTaxes,
    PutV1ExternalPayrollTaxesTypedDict,
)
from .put_v1_garnishments_garnishment_idop import (
    PutV1GarnishmentsGarnishmentIDRequest,
    PutV1GarnishmentsGarnishmentIDRequestBody,
    PutV1GarnishmentsGarnishmentIDRequestBodyTypedDict,
    PutV1GarnishmentsGarnishmentIDRequestTypedDict,
)
from .put_v1_historical_employeesop import (
    PutV1HistoricalEmployeesEmployeeStateTaxes,
    PutV1HistoricalEmployeesEmployeeStateTaxesTypedDict,
    PutV1HistoricalEmployeesHomeAddress,
    PutV1HistoricalEmployeesHomeAddressTypedDict,
    PutV1HistoricalEmployeesJob,
    PutV1HistoricalEmployeesJobTypedDict,
    PutV1HistoricalEmployeesRequest,
    PutV1HistoricalEmployeesRequestBody,
    PutV1HistoricalEmployeesRequestBodyTypedDict,
    PutV1HistoricalEmployeesRequestTypedDict,
    PutV1HistoricalEmployeesTermination,
    PutV1HistoricalEmployeesTerminationTypedDict,
    PutV1HistoricalEmployeesWorkAddress,
    PutV1HistoricalEmployeesWorkAddressTypedDict,
)
from .put_v1_home_addresses_home_address_uuidop import (
    PutV1HomeAddressesHomeAddressUUIDRequest,
    PutV1HomeAddressesHomeAddressUUIDRequestBody,
    PutV1HomeAddressesHomeAddressUUIDRequestBodyTypedDict,
    PutV1HomeAddressesHomeAddressUUIDRequestTypedDict,
)
from .put_v1_jobs_job_idop import (
    PutV1JobsJobIDRequest,
    PutV1JobsJobIDRequestBody,
    PutV1JobsJobIDRequestBodyTypedDict,
    PutV1JobsJobIDRequestTypedDict,
)
from .put_v1_locations_location_idop import (
    PutV1LocationsLocationIDRequest,
    PutV1LocationsLocationIDRequestBody,
    PutV1LocationsLocationIDRequestBodyTypedDict,
    PutV1LocationsLocationIDRequestTypedDict,
)
from .put_v1_partner_managed_companies_company_uuid_migrateop import (
    MigrationStatus,
    PutV1PartnerManagedCompaniesCompanyUUIDMigrateRequest,
    PutV1PartnerManagedCompaniesCompanyUUIDMigrateRequestBody,
    PutV1PartnerManagedCompaniesCompanyUUIDMigrateRequestBodyTypedDict,
    PutV1PartnerManagedCompaniesCompanyUUIDMigrateRequestTypedDict,
    PutV1PartnerManagedCompaniesCompanyUUIDMigrateResponseBody,
    PutV1PartnerManagedCompaniesCompanyUUIDMigrateResponseBodyTypedDict,
)
from .put_v1_tax_liabilities_finishop import (
    PutV1TaxLiabilitiesFinishRequest,
    PutV1TaxLiabilitiesFinishRequestTypedDict,
)
from .put_v1_tax_liabilitiesop import (
    LiabilitySelections,
    LiabilitySelectionsTypedDict,
    PutV1TaxLiabilitiesRequest,
    PutV1TaxLiabilitiesRequestBody,
    PutV1TaxLiabilitiesRequestBodyTypedDict,
    PutV1TaxLiabilitiesRequestTypedDict,
)
from .put_v1_terminations_employee_idop import (
    PutV1TerminationsEmployeeIDRequest,
    PutV1TerminationsEmployeeIDRequestBody,
    PutV1TerminationsEmployeeIDRequestBodyTypedDict,
    PutV1TerminationsEmployeeIDRequestTypedDict,
)
from .put_v1_time_off_policies_time_off_policy_uuid_deactivateop import (
    PutV1TimeOffPoliciesTimeOffPolicyUUIDDeactivateRequest,
    PutV1TimeOffPoliciesTimeOffPolicyUUIDDeactivateRequestTypedDict,
)
from .put_v1_time_off_policies_time_off_policy_uuid_remove_employeesop import (
    PutV1TimeOffPoliciesTimeOffPolicyUUIDRemoveEmployeesEmployees,
    PutV1TimeOffPoliciesTimeOffPolicyUUIDRemoveEmployeesEmployeesTypedDict,
    PutV1TimeOffPoliciesTimeOffPolicyUUIDRemoveEmployeesRequest,
    PutV1TimeOffPoliciesTimeOffPolicyUUIDRemoveEmployeesRequestBody,
    PutV1TimeOffPoliciesTimeOffPolicyUUIDRemoveEmployeesRequestBodyTypedDict,
    PutV1TimeOffPoliciesTimeOffPolicyUUIDRemoveEmployeesRequestTypedDict,
)
from .put_v1_verify_webhook_subscription_uuidop import (
    PutV1VerifyWebhookSubscriptionUUIDRequest,
    PutV1VerifyWebhookSubscriptionUUIDRequestBody,
    PutV1VerifyWebhookSubscriptionUUIDRequestBodyTypedDict,
    PutV1VerifyWebhookSubscriptionUUIDRequestTypedDict,
    PutV1VerifyWebhookSubscriptionUUIDSecurity,
    PutV1VerifyWebhookSubscriptionUUIDSecurityTypedDict,
)
from .put_v1_webhook_subscription_uuidop import (
    PutV1WebhookSubscriptionUUIDRequest,
    PutV1WebhookSubscriptionUUIDRequestBody,
    PutV1WebhookSubscriptionUUIDRequestBodyTypedDict,
    PutV1WebhookSubscriptionUUIDRequestTypedDict,
    PutV1WebhookSubscriptionUUIDSecurity,
    PutV1WebhookSubscriptionUUIDSecurityTypedDict,
    PutV1WebhookSubscriptionUUIDSubscriptionTypes,
)
from .put_v1_work_addresses_work_address_uuidop import (
    PutV1WorkAddressesWorkAddressUUIDRequest,
    PutV1WorkAddressesWorkAddressUUIDRequestBody,
    PutV1WorkAddressesWorkAddressUUIDRequestBodyTypedDict,
    PutV1WorkAddressesWorkAddressUUIDRequestTypedDict,
)
from .put_version_time_off_policies_time_off_policy_uuid_add_employeesop import (
    PutVersionTimeOffPoliciesTimeOffPolicyUUIDAddEmployeesEmployees,
    PutVersionTimeOffPoliciesTimeOffPolicyUUIDAddEmployeesEmployeesTypedDict,
    PutVersionTimeOffPoliciesTimeOffPolicyUUIDAddEmployeesRequest,
    PutVersionTimeOffPoliciesTimeOffPolicyUUIDAddEmployeesRequestBody,
    PutVersionTimeOffPoliciesTimeOffPolicyUUIDAddEmployeesRequestBodyTypedDict,
    PutVersionTimeOffPoliciesTimeOffPolicyUUIDAddEmployeesRequestTypedDict,
)
from .put_version_time_off_policies_time_off_policy_uuid_balanceop import (
    PutVersionTimeOffPoliciesTimeOffPolicyUUIDBalanceEmployees,
    PutVersionTimeOffPoliciesTimeOffPolicyUUIDBalanceEmployeesTypedDict,
    PutVersionTimeOffPoliciesTimeOffPolicyUUIDBalanceRequest,
    PutVersionTimeOffPoliciesTimeOffPolicyUUIDBalanceRequestBody,
    PutVersionTimeOffPoliciesTimeOffPolicyUUIDBalanceRequestBodyTypedDict,
    PutVersionTimeOffPoliciesTimeOffPolicyUUIDBalanceRequestTypedDict,
)
from .put_wire_in_requests_wire_in_request_uuidop import (
    PutWireInRequestsWireInRequestUUIDRequest,
    PutWireInRequestsWireInRequestUUIDRequestBody,
    PutWireInRequestsWireInRequestUUIDRequestBodyTypedDict,
    PutWireInRequestsWireInRequestUUIDRequestTypedDict,
)
from .recovery_case import RecoveryCase, RecoveryCaseStatus, RecoveryCaseTypedDict
from .redebit_recovery_caseop import (
    RedebitRecoveryCaseRequest,
    RedebitRecoveryCaseRequestTypedDict,
)
from .refresh_access_tokenop import (
    RefreshAccessTokenRequest,
    RefreshAccessTokenRequestBody,
    RefreshAccessTokenRequestBodyTypedDict,
    RefreshAccessTokenRequestTypedDict,
)
from .rehire import Rehire, RehireEmploymentStatus, RehireTypedDict
from .rehire_body import EmploymentStatus, RehireBody, RehireBodyTypedDict
from .report import Report, ReportTypedDict
from .report_template import ReportTemplate, ReportTemplateTypedDict
from .security import Security, SecurityTypedDict
from .signatory import (
    HomeAddress,
    HomeAddressTypedDict,
    IdentityVerificationStatus,
    Signatory,
    SignatoryTypedDict,
)
from .sort_order import SortOrder
from .supported_benefit import SupportedBenefit, SupportedBenefitTypedDict
from .tax_liabilities_selections import (
    PossibleLiabilities,
    PossibleLiabilitiesTypedDict,
    TaxLiabilitiesSelections,
    TaxLiabilitiesSelectionsTypedDict,
)
from .tax_requirement import (
    ApplicableIf,
    ApplicableIfTypedDict,
    TaxRequirement,
    TaxRequirementTypedDict,
    TaxRequirementValue,
    TaxRequirementValueTypedDict,
)
from .tax_requirement_metadata import (
    RateType,
    TaxRequirementMetadata,
    TaxRequirementMetadataOptions,
    TaxRequirementMetadataOptionsTypedDict,
    TaxRequirementMetadataType,
    TaxRequirementMetadataTypedDict,
    TaxRequirementMetadataValidationType,
    TaxRequirementMetadataValue,
    TaxRequirementMetadataValueTypedDict,
    Validation,
    ValidationTypedDict,
)
from .tax_requirement_set import TaxRequirementSet, TaxRequirementSetTypedDict
from .tax_requirements_state import TaxRequirementsState, TaxRequirementsStateTypedDict
from .termination import Termination, TerminationTypedDict
from .time_off_activity import TimeOffActivity, TimeOffActivityTypedDict, TimeOffType
from .time_off_policy import (
    PolicyType,
    TimeOffPolicy,
    TimeOffPolicyEmployees,
    TimeOffPolicyEmployeesTypedDict,
    TimeOffPolicyTypedDict,
)
from .unprocessable_entity_error_object import (
    UnprocessableEntityErrorObject,
    UnprocessableEntityErrorObjectData,
)
from .unprocessed_termination_pay_period import (
    UnprocessedTerminationPayPeriod,
    UnprocessedTerminationPayPeriodTypedDict,
)
from .versionheader import VersionHeader
from .webhook_subscription import (
    SubscriptionTypes,
    WebhookSubscription,
    WebhookSubscriptionStatus,
    WebhookSubscriptionTypedDict,
)
from .wire_in_request import (
    PaymentUUID,
    WireInRequest,
    WireInRequestStatus,
    WireInRequestTypedDict,
)
from .ytd_benefit_amounts_from_different_company import (
    YtdBenefitAmountsFromDifferentCompany,
    YtdBenefitAmountsFromDifferentCompanyTypedDict,
)


__all__ = [
    "APIError",
    "AccountType",
    "AccrualMethod",
    "AccruingTimeOffHour",
    "AccruingTimeOffHourTypedDict",
    "AchTransaction",
    "AchTransactionRecipientType",
    "AchTransactionTypedDict",
    "ActiveCompanies",
    "ActiveCompaniesTypedDict",
    "Address",
    "AddressTypedDict",
    "Admin",
    "AdminTypedDict",
    "Agencies",
    "AgenciesTypedDict",
    "Answers",
    "AnswersTypedDict",
    "ApplicableBenefits",
    "ApplicableBenefitsTypedDict",
    "ApplicableEarnings",
    "ApplicableEarningsTypedDict",
    "ApplicableIf",
    "ApplicableIfTypedDict",
    "ApplicableTaxes",
    "ApplicableTaxesTypedDict",
    "Authentication",
    "AuthenticationTypedDict",
    "AuthorizationStatus",
    "Base",
    "BaseTypedDict",
    "BenefitSummary",
    "BenefitSummaryEmployees",
    "BenefitSummaryEmployeesTypedDict",
    "BenefitSummaryPayPeriod",
    "BenefitSummaryPayPeriodTypedDict",
    "BenefitSummaryTypedDict",
    "BenefitTypeRequirements",
    "BenefitTypeRequirementsCatchUpDefaultValue",
    "BenefitTypeRequirementsCatchUpDefaultValueTypedDict",
    "BenefitTypeRequirementsCompanyContributionAnnualMaximumDefaultValue",
    "BenefitTypeRequirementsCompanyContributionAnnualMaximumDefaultValueTypedDict",
    "BenefitTypeRequirementsContribution",
    "BenefitTypeRequirementsContributionTypedDict",
    "BenefitTypeRequirementsCoverageAmountDefaultValue",
    "BenefitTypeRequirementsCoverageAmountDefaultValueTypedDict",
    "BenefitTypeRequirementsCoverageSalaryMultiplierDefaultValue",
    "BenefitTypeRequirementsCoverageSalaryMultiplierDefaultValueTypedDict",
    "BenefitTypeRequirementsDeductAsPercentageDefaultValue",
    "BenefitTypeRequirementsDeductAsPercentageDefaultValueTypedDict",
    "BenefitTypeRequirementsDefaultValue",
    "BenefitTypeRequirementsDefaultValueTypedDict",
    "BenefitTypeRequirementsLimitOptionDefaultValue",
    "BenefitTypeRequirementsLimitOptionDefaultValueTypedDict",
    "BenefitTypeRequirementsTypedDict",
    "Benefits",
    "BenefitsTypedDict",
    "CatchUp",
    "CatchUpTypedDict",
    "Category",
    "CheckDate",
    "CheckDateTypedDict",
    "ChildSupportData",
    "ChildSupportDataTypedDict",
    "ChristmasDay",
    "ChristmasDayTypedDict",
    "ColumbusDay",
    "ColumbusDayTypedDict",
    "Columns",
    "Company",
    "CompanyAddress",
    "CompanyAddressTypedDict",
    "CompanyAttachment",
    "CompanyAttachmentTypedDict",
    "CompanyBankAccount",
    "CompanyBankAccountTypedDict",
    "CompanyBenefit",
    "CompanyBenefitTypedDict",
    "CompanyBenefitWithEmployeeBenefits",
    "CompanyBenefitWithEmployeeBenefitsContribution",
    "CompanyBenefitWithEmployeeBenefitsContributionTypedDict",
    "CompanyBenefitWithEmployeeBenefitsTypedDict",
    "CompanyBenefitWithEmployeeBenefitsValue",
    "CompanyBenefitWithEmployeeBenefitsValue2",
    "CompanyBenefitWithEmployeeBenefitsValue2TypedDict",
    "CompanyBenefitWithEmployeeBenefitsValueTiers",
    "CompanyBenefitWithEmployeeBenefitsValueTiersTypedDict",
    "CompanyBenefitWithEmployeeBenefitsValueTypedDict",
    "CompanyContributionAnnualMaximum",
    "CompanyContributionAnnualMaximumTypedDict",
    "CompanyCustomField",
    "CompanyCustomFieldList",
    "CompanyCustomFieldListTypedDict",
    "CompanyCustomFieldTypedDict",
    "CompanyHomeAddress",
    "CompanyHomeAddressTypedDict",
    "CompanyOnboardingStatus",
    "CompanyOnboardingStatusTypedDict",
    "CompanyPaidTimeOff",
    "CompanyPaidTimeOffTypedDict",
    "CompanyStatus",
    "CompanyTypedDict",
    "Compensation",
    "CompensationTypedDict",
    "Compensations",
    "CompensationsTypedDict",
    "Contractor",
    "ContractorAddress",
    "ContractorAddressTypedDict",
    "ContractorBankAccount",
    "ContractorBankAccountAccountType",
    "ContractorBankAccountTypedDict",
    "ContractorOnboardingStatus",
    "ContractorOnboardingStatus1",
    "ContractorOnboardingStatusOnboardingStatus",
    "ContractorOnboardingStatusOnboardingStep",
    "ContractorOnboardingStatusOnboardingStepTypedDict",
    "ContractorOnboardingStatusTypedDict",
    "ContractorPayment",
    "ContractorPaymentForGroup",
    "ContractorPaymentForGroupPaymentMethod",
    "ContractorPaymentForGroupStatus",
    "ContractorPaymentForGroupTypedDict",
    "ContractorPaymentForGroupWageType",
    "ContractorPaymentGroup",
    "ContractorPaymentGroupMinimal",
    "ContractorPaymentGroupMinimalStatus",
    "ContractorPaymentGroupMinimalTotals",
    "ContractorPaymentGroupMinimalTotalsTypedDict",
    "ContractorPaymentGroupMinimalTypedDict",
    "ContractorPaymentGroupStatus",
    "ContractorPaymentGroupTotals",
    "ContractorPaymentGroupTotalsTypedDict",
    "ContractorPaymentGroupTypedDict",
    "ContractorPaymentMethod",
    "ContractorPaymentMethod1",
    "ContractorPaymentMethodSplitBy",
    "ContractorPaymentMethodType",
    "ContractorPaymentMethodTypedDict",
    "ContractorPaymentPaymentMethod",
    "ContractorPaymentReceipt",
    "ContractorPaymentReceiptLicensee",
    "ContractorPaymentReceiptLicenseeTypedDict",
    "ContractorPaymentReceiptTotals",
    "ContractorPaymentReceiptTotalsTypedDict",
    "ContractorPaymentReceiptTypedDict",
    "ContractorPaymentStatus",
    "ContractorPaymentSummary",
    "ContractorPaymentSummaryByDates",
    "ContractorPaymentSummaryByDatesContractorPayments",
    "ContractorPaymentSummaryByDatesContractorPaymentsTypedDict",
    "ContractorPaymentSummaryByDatesTotal",
    "ContractorPaymentSummaryByDatesTotalTypedDict",
    "ContractorPaymentSummaryByDatesTypedDict",
    "ContractorPaymentSummaryContractorPayments",
    "ContractorPaymentSummaryContractorPaymentsTypedDict",
    "ContractorPaymentSummaryTypedDict",
    "ContractorPaymentTypedDict",
    "ContractorPaymentWageType",
    "ContractorPaymentsModel",
    "ContractorPaymentsModelTypedDict",
    "ContractorType",
    "ContractorTypedDict",
    "ContractorsModel",
    "ContractorsModelTypedDict",
    "Contribution",
    "ContributionTypedDict",
    "CoverageAmount",
    "CoverageAmountTypedDict",
    "CoverageSalaryMultiplier",
    "CoverageSalaryMultiplierTypedDict",
    "CreateReport",
    "CreateReportTypedDict",
    "CurrentEmploymentStatus",
    "CustomFieldType",
    "DeductAsPercentage",
    "DeductAsPercentageTypedDict",
    "DeductionReducesTaxableIncome",
    "Deductions",
    "DeductionsTypedDict",
    "DefaultValue",
    "DefaultValueTypedDict",
    "DeleteCompaniesCompanyUUIDHolidayPayPolicyRequest",
    "DeleteCompaniesCompanyUUIDHolidayPayPolicyRequestTypedDict",
    "DeleteDepartmentRequest",
    "DeleteDepartmentRequestTypedDict",
    "DeleteV1CompaniesCompanyIDContractorPaymentContractorPaymentRequest",
    "DeleteV1CompaniesCompanyIDContractorPaymentContractorPaymentRequestTypedDict",
    "DeleteV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequest",
    "DeleteV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequestTypedDict",
    "DeleteV1CompaniesCompanyIDPayrollsRequest",
    "DeleteV1CompaniesCompanyIDPayrollsRequestTypedDict",
    "DeleteV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDRequest",
    "DeleteV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDRequestTypedDict",
    "DeleteV1CompanyBenefitsCompanyBenefitIDErrors",
    "DeleteV1CompanyBenefitsCompanyBenefitIDErrorsTypedDict",
    "DeleteV1CompanyBenefitsCompanyBenefitIDRequest",
    "DeleteV1CompanyBenefitsCompanyBenefitIDRequestTypedDict",
    "DeleteV1CompanyBenefitsCompanyBenefitIDResponseBody",
    "DeleteV1CompanyBenefitsCompanyBenefitIDResponseBodyData",
    "DeleteV1CompensationsCompensationIDRequest",
    "DeleteV1CompensationsCompensationIDRequestTypedDict",
    "DeleteV1ContractorPaymentGroupsContractorPaymentGroupIDRequest",
    "DeleteV1ContractorPaymentGroupsContractorPaymentGroupIDRequestTypedDict",
    "DeleteV1ContractorsContractorUUIDRequest",
    "DeleteV1ContractorsContractorUUIDRequestTypedDict",
    "DeleteV1EmployeeBenefitsEmployeeBenefitIDRequest",
    "DeleteV1EmployeeBenefitsEmployeeBenefitIDRequestTypedDict",
    "DeleteV1EmployeeRequest",
    "DeleteV1EmployeeRequestTypedDict",
    "DeleteV1EmployeesEmployeeIDBankAccountsBankAccountIDRequest",
    "DeleteV1EmployeesEmployeeIDBankAccountsBankAccountIDRequestTypedDict",
    "DeleteV1EmployeesEmployeeIDI9AuthorizationDocumentsDocumentIDRequest",
    "DeleteV1EmployeesEmployeeIDI9AuthorizationDocumentsDocumentIDRequestTypedDict",
    "DeleteV1EmployeesEmployeeIDRehireRequest",
    "DeleteV1EmployeesEmployeeIDRehireRequestTypedDict",
    "DeleteV1EmployeesEmployeeIDTerminationsRequest",
    "DeleteV1EmployeesEmployeeIDTerminationsRequestTypedDict",
    "DeleteV1ExternalPayrollRequest",
    "DeleteV1ExternalPayrollRequestTypedDict",
    "DeleteV1HomeAddressesHomeAddressUUIDRequest",
    "DeleteV1HomeAddressesHomeAddressUUIDRequestTypedDict",
    "DeleteV1JobsJobIDRequest",
    "DeleteV1JobsJobIDRequestTypedDict",
    "DeleteV1WebhookSubscriptionUUIDRequest",
    "DeleteV1WebhookSubscriptionUUIDRequestTypedDict",
    "DeleteV1WebhookSubscriptionUUIDSecurity",
    "DeleteV1WebhookSubscriptionUUIDSecurityTypedDict",
    "DeleteV1WorkAddressesWorkAddressUUIDRequest",
    "DeleteV1WorkAddressesWorkAddressUUIDRequestTypedDict",
    "Department",
    "DepartmentEmployees",
    "DepartmentEmployeesTypedDict",
    "DepartmentTypedDict",
    "DepartmentsModel",
    "DepartmentsModelTypedDict",
    "Document",
    "DocumentPdf",
    "DocumentPdfTypedDict",
    "DocumentSigned",
    "DocumentSignedRecipientType",
    "DocumentSignedTypedDict",
    "DocumentType",
    "DocumentTypedDict",
    "Documents",
    "DocumentsTypedDict",
    "EarningType",
    "EarningTypeList",
    "EarningTypeListTypedDict",
    "EarningTypeTypedDict",
    "Earnings",
    "EarningsTypedDict",
    "Employee",
    "EmployeeAddress",
    "EmployeeAddressTypedDict",
    "EmployeeBankAccount",
    "EmployeeBankAccountAccountType",
    "EmployeeBankAccountTypedDict",
    "EmployeeBenefit",
    "EmployeeBenefitForCompanyBenefit",
    "EmployeeBenefitForCompanyBenefitContribution",
    "EmployeeBenefitForCompanyBenefitContributionTypedDict",
    "EmployeeBenefitForCompanyBenefitDeductionReducesTaxableIncome",
    "EmployeeBenefitForCompanyBenefitTypedDict",
    "EmployeeBenefitForCompanyBenefitValue",
    "EmployeeBenefitForCompanyBenefitValueTypedDict",
    "EmployeeBenefitTypedDict",
    "EmployeeBenefitValue",
    "EmployeeBenefitValueTypedDict",
    "EmployeeBenefitsModel",
    "EmployeeBenefitsModelTypedDict",
    "EmployeeCheckNumberMapping",
    "EmployeeCheckNumberMappingTypedDict",
    "EmployeeCompensations",
    "EmployeeCompensationsTypedDict",
    "EmployeeCustomField",
    "EmployeeCustomFieldTypedDict",
    "EmployeeDeduction",
    "EmployeeDeductionTypedDict",
    "EmployeeFederalTax",
    "EmployeeFederalTaxTypedDict",
    "EmployeeOnboardingDocument",
    "EmployeeOnboardingDocumentTypedDict",
    "EmployeeOnboardingStatus",
    "EmployeeOnboardingStatusOnboardingStep",
    "EmployeeOnboardingStatusOnboardingStepTypedDict",
    "EmployeeOnboardingStatusTypedDict",
    "EmployeePayStub",
    "EmployeePayStubTypedDict",
    "EmployeePaymentMethod",
    "EmployeePaymentMethodType",
    "EmployeePaymentMethodTypedDict",
    "EmployeeStateTax",
    "EmployeeStateTaxAnswer",
    "EmployeeStateTaxAnswerTypedDict",
    "EmployeeStateTaxInputQuestionFormat",
    "EmployeeStateTaxInputQuestionFormatTypedDict",
    "EmployeeStateTaxInputQuestionFormatValue",
    "EmployeeStateTaxInputQuestionFormatValueTypedDict",
    "EmployeeStateTaxQuestion",
    "EmployeeStateTaxQuestionTypedDict",
    "EmployeeStateTaxTypedDict",
    "EmployeeStateTaxes",
    "EmployeeStateTaxesTypedDict",
    "EmployeeTypedDict",
    "EmployeeWorkAddress",
    "EmployeeWorkAddressTypedDict",
    "EmployeesModel",
    "EmployeesModelTypedDict",
    "EmploymentHistoryList",
    "EmploymentHistoryListEmploymentStatus",
    "EmploymentHistoryListTypedDict",
    "EmploymentStatus",
    "EmploymentType",
    "EntityErrorObject",
    "EntityErrorObjectTypedDict",
    "EntityType",
    "Errors",
    "ErrorsTypedDict",
    "Event",
    "EventTypedDict",
    "ExternalPayroll",
    "ExternalPayrollBasic",
    "ExternalPayrollBasicStatus",
    "ExternalPayrollBasicTypedDict",
    "ExternalPayrollBenefits",
    "ExternalPayrollBenefitsTypedDict",
    "ExternalPayrollItems",
    "ExternalPayrollItemsTypedDict",
    "ExternalPayrollMetadata",
    "ExternalPayrollMetadataTypedDict",
    "ExternalPayrollTaxSuggestions",
    "ExternalPayrollTaxSuggestionsTypedDict",
    "ExternalPayrollTaxes",
    "ExternalPayrollTaxesTypedDict",
    "ExternalPayrollTypedDict",
    "FastPaymentLimitRequiredBody",
    "FastPaymentLimitRequiredBodyTypedDict",
    "FederalHolidays",
    "FederalHolidaysTypedDict",
    "FederalTaxDetails",
    "FederalTaxDetailsTypedDict",
    "Fields",
    "FieldsTypedDict",
    "FileType",
    "FilingForm",
    "FipsCodes",
    "FipsCodesTypedDict",
    "Fixed",
    "FixedCompensations",
    "FixedCompensationsTypedDict",
    "FixedTypedDict",
    "Flow",
    "FlowTypedDict",
    "FlsaStatusType",
    "Form",
    "Form1099",
    "Form1099TypedDict",
    "FormPdf",
    "FormPdfTypedDict",
    "FormTypedDict",
    "Frequency",
    "FundingType",
    "Garnishment",
    "GarnishmentChildSupport",
    "GarnishmentChildSupportTypedDict",
    "GarnishmentType",
    "GarnishmentTypedDict",
    "GeneratedDocument",
    "GeneratedDocumentStatus",
    "GeneratedDocumentTypedDict",
    "GetAchTransactionsRequest",
    "GetAchTransactionsRequestTypedDict",
    "GetCompaniesCompanyUUIDContractorPaymentsPreviewBase",
    "GetCompaniesCompanyUUIDContractorPaymentsPreviewBaseTypedDict",
    "GetCompaniesCompanyUUIDContractorPaymentsPreviewContractorPayments",
    "GetCompaniesCompanyUUIDContractorPaymentsPreviewContractorPaymentsResponseBody",
    "GetCompaniesCompanyUUIDContractorPaymentsPreviewContractorPaymentsResponseBodyData",
    "GetCompaniesCompanyUUIDContractorPaymentsPreviewContractorPaymentsTypedDict",
    "GetCompaniesCompanyUUIDContractorPaymentsPreviewErrors",
    "GetCompaniesCompanyUUIDContractorPaymentsPreviewErrorsTypedDict",
    "GetCompaniesCompanyUUIDContractorPaymentsPreviewRequest",
    "GetCompaniesCompanyUUIDContractorPaymentsPreviewRequestBody",
    "GetCompaniesCompanyUUIDContractorPaymentsPreviewRequestBodyTypedDict",
    "GetCompaniesCompanyUUIDContractorPaymentsPreviewRequestTypedDict",
    "GetCompaniesCompanyUUIDContractorPaymentsPreviewResponseBody",
    "GetCompaniesCompanyUUIDContractorPaymentsPreviewResponseBodyTypedDict",
    "GetCompaniesCompanyUUIDHolidayPayPolicyRequest",
    "GetCompaniesCompanyUUIDHolidayPayPolicyRequestTypedDict",
    "GetCompaniesCompanyUUIDPaidHolidaysRequest",
    "GetCompaniesCompanyUUIDPaidHolidaysRequestBody",
    "GetCompaniesCompanyUUIDPaidHolidaysRequestBodyTypedDict",
    "GetCompaniesCompanyUUIDPaidHolidaysRequestTypedDict",
    "GetCompaniesCompanyUUIDReportTemplatesReportTypeRequest",
    "GetCompaniesCompanyUUIDReportTemplatesReportTypeRequestTypedDict",
    "GetCompaniesCompanyUUIDTimeOffPoliciesRequest",
    "GetCompaniesCompanyUUIDTimeOffPoliciesRequestTypedDict",
    "GetCompaniesCompanyUUIDWireInRequestUUIDRequest",
    "GetCompaniesCompanyUUIDWireInRequestUUIDRequestTypedDict",
    "GetCompaniesDepartmentsRequest",
    "GetCompaniesDepartmentsRequestTypedDict",
    "GetDepartmentRequest",
    "GetDepartmentRequestTypedDict",
    "GetEmployeeYtdBenefitAmountsFromDifferentCompanyRequest",
    "GetEmployeeYtdBenefitAmountsFromDifferentCompanyRequestTypedDict",
    "GetEventsRequest",
    "GetEventsRequestTypedDict",
    "GetEventsSecurity",
    "GetEventsSecurityTypedDict",
    "GetInvoicesInvoicePeriodRequest",
    "GetInvoicesInvoicePeriodRequestTypedDict",
    "GetInvoicesInvoicePeriodSecurity",
    "GetInvoicesInvoicePeriodSecurityTypedDict",
    "GetNotificationsNotificationUUIDRequest",
    "GetNotificationsNotificationUUIDRequestTypedDict",
    "GetRecoveryCasesRequest",
    "GetRecoveryCasesRequestTypedDict",
    "GetReportsReportUUIDRequest",
    "GetReportsReportUUIDRequestTypedDict",
    "GetTimeOffPoliciesTimeOffPolicyUUIDRequest",
    "GetTimeOffPoliciesTimeOffPolicyUUIDRequestTypedDict",
    "GetV1BenefitsBenefitIDRequest",
    "GetV1BenefitsBenefitIDRequestTypedDict",
    "GetV1BenefitsBenefitsIDRequirementsRequest",
    "GetV1BenefitsBenefitsIDRequirementsRequestTypedDict",
    "GetV1BenefitsCompanyBenefitIDSummaryRequest",
    "GetV1BenefitsCompanyBenefitIDSummaryRequestTypedDict",
    "GetV1BenefitsRequest",
    "GetV1BenefitsRequestTypedDict",
    "GetV1CompaniesAttachmentRequest",
    "GetV1CompaniesAttachmentRequestTypedDict",
    "GetV1CompaniesAttachmentURLRequest",
    "GetV1CompaniesAttachmentURLRequestTypedDict",
    "GetV1CompaniesAttachmentURLResponseBody",
    "GetV1CompaniesAttachmentURLResponseBodyTypedDict",
    "GetV1CompaniesAttachmentsRequest",
    "GetV1CompaniesAttachmentsRequestTypedDict",
    "GetV1CompaniesCompanyIDAdminsRequest",
    "GetV1CompaniesCompanyIDAdminsRequestTypedDict",
    "GetV1CompaniesCompanyIDBankAccountsRequest",
    "GetV1CompaniesCompanyIDBankAccountsRequestTypedDict",
    "GetV1CompaniesCompanyIDCompanyBenefitsRequest",
    "GetV1CompaniesCompanyIDCompanyBenefitsRequestTypedDict",
    "GetV1CompaniesCompanyIDContractorPaymentContractorPaymentRequest",
    "GetV1CompaniesCompanyIDContractorPaymentContractorPaymentRequestTypedDict",
    "GetV1CompaniesCompanyIDContractorPaymentGroupsRequest",
    "GetV1CompaniesCompanyIDContractorPaymentGroupsRequestTypedDict",
    "GetV1CompaniesCompanyIDContractorPaymentsRequest",
    "GetV1CompaniesCompanyIDContractorPaymentsRequestTypedDict",
    "GetV1CompaniesCompanyIDContractorPaymentsResponseBody",
    "GetV1CompaniesCompanyIDContractorPaymentsResponseBodyTypedDict",
    "GetV1CompaniesCompanyIDCustomFieldsRequest",
    "GetV1CompaniesCompanyIDCustomFieldsRequestTypedDict",
    "GetV1CompaniesCompanyIDEarningTypesRequest",
    "GetV1CompaniesCompanyIDEarningTypesRequestTypedDict",
    "GetV1CompaniesCompanyIDEmployeesRequest",
    "GetV1CompaniesCompanyIDEmployeesRequestTypedDict",
    "GetV1CompaniesCompanyIDFederalTaxDetailsRequest",
    "GetV1CompaniesCompanyIDFederalTaxDetailsRequestTypedDict",
    "GetV1CompaniesCompanyIDLocationsRequest",
    "GetV1CompaniesCompanyIDLocationsRequestTypedDict",
    "GetV1CompaniesCompanyIDPayPeriodsRequest",
    "GetV1CompaniesCompanyIDPayPeriodsRequestTypedDict",
    "GetV1CompaniesCompanyIDPaySchedulesAssignmentsRequest",
    "GetV1CompaniesCompanyIDPaySchedulesAssignmentsRequestTypedDict",
    "GetV1CompaniesCompanyIDPaySchedulesPayScheduleIDRequest",
    "GetV1CompaniesCompanyIDPaySchedulesPayScheduleIDRequestTypedDict",
    "GetV1CompaniesCompanyIDPaySchedulesPreviewRequest",
    "GetV1CompaniesCompanyIDPaySchedulesPreviewRequestTypedDict",
    "GetV1CompaniesCompanyIDPaySchedulesPreviewResponseBody",
    "GetV1CompaniesCompanyIDPaySchedulesPreviewResponseBodyTypedDict",
    "GetV1CompaniesCompanyIDPaySchedulesRequest",
    "GetV1CompaniesCompanyIDPaySchedulesRequestTypedDict",
    "GetV1CompaniesCompanyIDPayrollReversalsRequest",
    "GetV1CompaniesCompanyIDPayrollReversalsRequestTypedDict",
    "GetV1CompaniesCompanyIDPayrollsPayrollIDQueryParamInclude",
    "GetV1CompaniesCompanyIDPayrollsPayrollIDRequest",
    "GetV1CompaniesCompanyIDPayrollsPayrollIDRequestTypedDict",
    "GetV1CompaniesCompanyIDPayrollsQueryParamInclude",
    "GetV1CompaniesCompanyIDPayrollsRequest",
    "GetV1CompaniesCompanyIDPayrollsRequestTypedDict",
    "GetV1CompaniesCompanyIDUnprocessedTerminationPayPeriodsRequest",
    "GetV1CompaniesCompanyIDUnprocessedTerminationPayPeriodsRequestTypedDict",
    "GetV1CompaniesCompanyUUIDContractorsRequest",
    "GetV1CompaniesCompanyUUIDContractorsRequestTypedDict",
    "GetV1CompaniesCompanyUUIDSignatoriesRequest",
    "GetV1CompaniesCompanyUUIDSignatoriesRequestTypedDict",
    "GetV1CompaniesCompanyUUIDTaxRequirementsRequest",
    "GetV1CompaniesCompanyUUIDTaxRequirementsRequestTypedDict",
    "GetV1CompaniesCompanyUUIDTaxRequirementsStateRequest",
    "GetV1CompaniesCompanyUUIDTaxRequirementsStateRequestTypedDict",
    "GetV1CompaniesPayrollBlockersCompanyUUIDRequest",
    "GetV1CompaniesPayrollBlockersCompanyUUIDRequestTypedDict",
    "GetV1CompaniesRequest",
    "GetV1CompaniesRequestTypedDict",
    "GetV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequest",
    "GetV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestTypedDict",
    "GetV1CompanyBenefitsCompanyBenefitIDRequest",
    "GetV1CompanyBenefitsCompanyBenefitIDRequestTypedDict",
    "GetV1CompanyExternalPayrollsRequest",
    "GetV1CompanyExternalPayrollsRequestTypedDict",
    "GetV1CompanyFinishOnboardingRequest",
    "GetV1CompanyFinishOnboardingRequestTypedDict",
    "GetV1CompanyFormPdfRequest",
    "GetV1CompanyFormPdfRequestTypedDict",
    "GetV1CompanyFormRequest",
    "GetV1CompanyFormRequestTypedDict",
    "GetV1CompanyFormsRequest",
    "GetV1CompanyFormsRequestTypedDict",
    "GetV1CompanyIndustryRequest",
    "GetV1CompanyIndustryRequestTypedDict",
    "GetV1CompanyOnboardingStatusRequest",
    "GetV1CompanyOnboardingStatusRequestTypedDict",
    "GetV1CompanyPaymentConfigsRequest",
    "GetV1CompanyPaymentConfigsRequestTypedDict",
    "GetV1CompensationsCompensationIDRequest",
    "GetV1CompensationsCompensationIDRequestTypedDict",
    "GetV1ContractorDocumentPdfRequest",
    "GetV1ContractorDocumentPdfRequestTypedDict",
    "GetV1ContractorDocumentRequest",
    "GetV1ContractorDocumentRequestTypedDict",
    "GetV1ContractorDocumentsRequest",
    "GetV1ContractorDocumentsRequestTypedDict",
    "GetV1ContractorFormPdfRequest",
    "GetV1ContractorFormPdfRequestTypedDict",
    "GetV1ContractorFormRequest",
    "GetV1ContractorFormRequestTypedDict",
    "GetV1ContractorFormsRequest",
    "GetV1ContractorFormsRequestTypedDict",
    "GetV1ContractorPaymentGroupsContractorPaymentGroupIDRequest",
    "GetV1ContractorPaymentGroupsContractorPaymentGroupIDRequestTypedDict",
    "GetV1ContractorPaymentsContractorPaymentUUIDFundRequest",
    "GetV1ContractorPaymentsContractorPaymentUUIDFundRequestTypedDict",
    "GetV1ContractorPaymentsContractorPaymentUUIDReceiptRequest",
    "GetV1ContractorPaymentsContractorPaymentUUIDReceiptRequestTypedDict",
    "GetV1ContractorsContractorUUIDAddressRequest",
    "GetV1ContractorsContractorUUIDAddressRequestTypedDict",
    "GetV1ContractorsContractorUUIDBankAccountsRequest",
    "GetV1ContractorsContractorUUIDBankAccountsRequestTypedDict",
    "GetV1ContractorsContractorUUIDOnboardingStatusRequest",
    "GetV1ContractorsContractorUUIDOnboardingStatusRequestTypedDict",
    "GetV1ContractorsContractorUUIDPaymentMethodRequest",
    "GetV1ContractorsContractorUUIDPaymentMethodRequestTypedDict",
    "GetV1ContractorsContractorUUIDRequest",
    "GetV1ContractorsContractorUUIDRequestTypedDict",
    "GetV1EmployeeBenefitsEmployeeBenefitIDRequest",
    "GetV1EmployeeBenefitsEmployeeBenefitIDRequestTypedDict",
    "GetV1EmployeeFormPdfRequest",
    "GetV1EmployeeFormPdfRequestTypedDict",
    "GetV1EmployeeFormRequest",
    "GetV1EmployeeFormRequestTypedDict",
    "GetV1EmployeeFormsRequest",
    "GetV1EmployeeFormsRequestTypedDict",
    "GetV1EmployeesEmployeeIDBankAccountsRequest",
    "GetV1EmployeesEmployeeIDBankAccountsRequestTypedDict",
    "GetV1EmployeesEmployeeIDCustomFieldsRequest",
    "GetV1EmployeesEmployeeIDCustomFieldsRequestTypedDict",
    "GetV1EmployeesEmployeeIDCustomFieldsResponseBody",
    "GetV1EmployeesEmployeeIDCustomFieldsResponseBodyTypedDict",
    "GetV1EmployeesEmployeeIDEmployeeBenefitsRequest",
    "GetV1EmployeesEmployeeIDEmployeeBenefitsRequestTypedDict",
    "GetV1EmployeesEmployeeIDEmploymentHistoryRequest",
    "GetV1EmployeesEmployeeIDEmploymentHistoryRequestTypedDict",
    "GetV1EmployeesEmployeeIDFederalTaxesRequest",
    "GetV1EmployeesEmployeeIDFederalTaxesRequestTypedDict",
    "GetV1EmployeesEmployeeIDGarnishmentsRequest",
    "GetV1EmployeesEmployeeIDGarnishmentsRequestTypedDict",
    "GetV1EmployeesEmployeeIDHomeAddressesRequest",
    "GetV1EmployeesEmployeeIDHomeAddressesRequestTypedDict",
    "GetV1EmployeesEmployeeIDI9AuthorizationDocumentOptionsRequest",
    "GetV1EmployeesEmployeeIDI9AuthorizationDocumentOptionsRequestTypedDict",
    "GetV1EmployeesEmployeeIDI9AuthorizationDocumentsRequest",
    "GetV1EmployeesEmployeeIDI9AuthorizationDocumentsRequestTypedDict",
    "GetV1EmployeesEmployeeIDI9AuthorizationRequest",
    "GetV1EmployeesEmployeeIDI9AuthorizationRequestTypedDict",
    "GetV1EmployeesEmployeeIDJobsQueryParamInclude",
    "GetV1EmployeesEmployeeIDJobsRequest",
    "GetV1EmployeesEmployeeIDJobsRequestTypedDict",
    "GetV1EmployeesEmployeeIDOnboardingStatusRequest",
    "GetV1EmployeesEmployeeIDOnboardingStatusRequestTypedDict",
    "GetV1EmployeesEmployeeIDPaymentMethodRequest",
    "GetV1EmployeesEmployeeIDPaymentMethodRequestTypedDict",
    "GetV1EmployeesEmployeeIDRehireRequest",
    "GetV1EmployeesEmployeeIDRehireRequestTypedDict",
    "GetV1EmployeesEmployeeIDStateTaxesRequest",
    "GetV1EmployeesEmployeeIDStateTaxesRequestTypedDict",
    "GetV1EmployeesEmployeeIDTerminationsRequest",
    "GetV1EmployeesEmployeeIDTerminationsRequestTypedDict",
    "GetV1EmployeesEmployeeIDWorkAddressesRequest",
    "GetV1EmployeesEmployeeIDWorkAddressesRequestTypedDict",
    "GetV1EmployeesEmployeeUUIDPayStubsRequest",
    "GetV1EmployeesEmployeeUUIDPayStubsRequestTypedDict",
    "GetV1EmployeesRequest",
    "GetV1EmployeesRequestTypedDict",
    "GetV1ExternalPayrollCalculateTaxesRequest",
    "GetV1ExternalPayrollCalculateTaxesRequestTypedDict",
    "GetV1ExternalPayrollRequest",
    "GetV1ExternalPayrollRequestTypedDict",
    "GetV1GarnishmentsChildSupportRequest",
    "GetV1GarnishmentsChildSupportRequestTypedDict",
    "GetV1GarnishmentsGarnishmentIDRequest",
    "GetV1GarnishmentsGarnishmentIDRequestTypedDict",
    "GetV1GeneratedDocumentsDocumentTypeRequestUUIDRequest",
    "GetV1GeneratedDocumentsDocumentTypeRequestUUIDRequestTypedDict",
    "GetV1HomeAddressesHomeAddressUUIDRequest",
    "GetV1HomeAddressesHomeAddressUUIDRequestTypedDict",
    "GetV1JobsJobIDCompensationsQueryParamInclude",
    "GetV1JobsJobIDCompensationsRequest",
    "GetV1JobsJobIDCompensationsRequestTypedDict",
    "GetV1JobsJobIDQueryParamInclude",
    "GetV1JobsJobIDRequest",
    "GetV1JobsJobIDRequestTypedDict",
    "GetV1LocationsLocationIDRequest",
    "GetV1LocationsLocationIDRequestTypedDict",
    "GetV1LocationsLocationUUIDMinimumWagesRequest",
    "GetV1LocationsLocationUUIDMinimumWagesRequestTypedDict",
    "GetV1PaymentReceiptsPayrollsPayrollUUIDRequest",
    "GetV1PaymentReceiptsPayrollsPayrollUUIDRequestTypedDict",
    "GetV1PayrollsPayrollUUIDEmployeesEmployeeUUIDPayStubRequest",
    "GetV1PayrollsPayrollUUIDEmployeesEmployeeUUIDPayStubRequestTypedDict",
    "GetV1TaxLiabilitiesRequest",
    "GetV1TaxLiabilitiesRequestTypedDict",
    "GetV1TokenInfoRequest",
    "GetV1TokenInfoRequestTypedDict",
    "GetV1TokenInfoResponseBody",
    "GetV1TokenInfoResponseBodyTypedDict",
    "GetV1TokenInfoType",
    "GetV1WebhookSubscriptionUUIDRequest",
    "GetV1WebhookSubscriptionUUIDRequestTypedDict",
    "GetV1WebhookSubscriptionUUIDSecurity",
    "GetV1WebhookSubscriptionUUIDSecurityTypedDict",
    "GetV1WebhookSubscriptionVerificationTokenUUIDRequest",
    "GetV1WebhookSubscriptionVerificationTokenUUIDRequestTypedDict",
    "GetV1WebhookSubscriptionVerificationTokenUUIDSecurity",
    "GetV1WebhookSubscriptionVerificationTokenUUIDSecurityTypedDict",
    "GetV1WebhookSubscriptionsRequest",
    "GetV1WebhookSubscriptionsRequestTypedDict",
    "GetV1WebhookSubscriptionsSecurity",
    "GetV1WebhookSubscriptionsSecurityTypedDict",
    "GetV1WorkAddressesWorkAddressUUIDRequest",
    "GetV1WorkAddressesWorkAddressUUIDRequestTypedDict",
    "GetVersionEmployeesTimeOffActivitiesRequest",
    "GetVersionEmployeesTimeOffActivitiesRequestTypedDict",
    "GetWireInRequestsWireInRequestUUIDRequest",
    "GetWireInRequestsWireInRequestUUIDRequestTypedDict",
    "GrossUpPay",
    "GrossUpPayTypedDict",
    "Groupings",
    "HistoricalEmployeeBody",
    "HistoricalEmployeeBodyHomeAddress",
    "HistoricalEmployeeBodyHomeAddressTypedDict",
    "HistoricalEmployeeBodyJob",
    "HistoricalEmployeeBodyJobTypedDict",
    "HistoricalEmployeeBodyTermination",
    "HistoricalEmployeeBodyTerminationTypedDict",
    "HistoricalEmployeeBodyTypedDict",
    "HolidayPayPolicy",
    "HolidayPayPolicyEmployees",
    "HolidayPayPolicyEmployeesTypedDict",
    "HolidayPayPolicyTypedDict",
    "HomeAddress",
    "HomeAddressTypedDict",
    "Hourly",
    "HourlyCompensations",
    "HourlyCompensationsTypedDict",
    "HourlyTypedDict",
    "I9Authorization",
    "I9AuthorizationDocument",
    "I9AuthorizationDocumentOption",
    "I9AuthorizationDocumentOptionTypedDict",
    "I9AuthorizationDocumentType",
    "I9AuthorizationDocumentTypedDict",
    "I9AuthorizationTypedDict",
    "ID",
    "IdentityVerificationStatus",
    "Include",
    "IndependenceDay",
    "IndependenceDayTypedDict",
    "Industry",
    "IndustryTypedDict",
    "InvoiceData",
    "InvoiceDataTypedDict",
    "Job",
    "JobTypedDict",
    "Juneteenth",
    "JuneteenthTypedDict",
    "Key",
    "LaborDay",
    "LaborDayTypedDict",
    "LiabilitySelections",
    "LiabilitySelectionsTypedDict",
    "Licensee",
    "LicenseeTypedDict",
    "LimitOption",
    "LimitOptionTypedDict",
    "Location",
    "LocationTypedDict",
    "MemorialDay",
    "MemorialDayTypedDict",
    "Metadata",
    "MetadataTypedDict",
    "MetadataWithMultipleEntities",
    "MetadataWithMultipleEntitiesTypedDict",
    "MetadataWithOneEntity",
    "MetadataWithOneEntityTypedDict",
    "MigrationStatus",
    "MinimumWage",
    "MinimumWageTypedDict",
    "MinimumWages",
    "MinimumWagesTypedDict",
    "MlkDay",
    "MlkDayTypedDict",
    "Name",
    "NewYearsDay",
    "NewYearsDayTypedDict",
    "Notification",
    "NotificationTypedDict",
    "OffCycleReason",
    "OffCycleReasonType",
    "OnboardingDocumentsConfig",
    "OnboardingDocumentsConfigTypedDict",
    "OnboardingStatus",
    "OnboardingStep",
    "OnboardingStepTypedDict",
    "Options",
    "OptionsTypedDict",
    "OwnerType",
    "Pages",
    "PagesTypedDict",
    "PaidHolidays",
    "PaidHolidaysTypedDict",
    "PaidTimeOff",
    "PaidTimeOffTypedDict",
    "PayPeriod",
    "PayPeriodPayroll",
    "PayPeriodPayrollTypedDict",
    "PayPeriodTypedDict",
    "PayPeriods",
    "PayPeriodsTypedDict",
    "PaySchedule",
    "PayScheduleAssignment",
    "PayScheduleAssignmentBody",
    "PayScheduleAssignmentBodyType",
    "PayScheduleAssignmentBodyTypedDict",
    "PayScheduleAssignmentDepartment",
    "PayScheduleAssignmentDepartmentTypedDict",
    "PayScheduleAssignmentEmployee",
    "PayScheduleAssignmentEmployeeChange",
    "PayScheduleAssignmentEmployeeChangeTypedDict",
    "PayScheduleAssignmentEmployeeTypedDict",
    "PayScheduleAssignmentPayPeriod",
    "PayScheduleAssignmentPayPeriodTypedDict",
    "PayScheduleAssignmentPreview",
    "PayScheduleAssignmentPreviewType",
    "PayScheduleAssignmentPreviewTypedDict",
    "PayScheduleAssignmentTransitionPayPeriod",
    "PayScheduleAssignmentTransitionPayPeriodTypedDict",
    "PayScheduleAssignmentTypedDict",
    "PayScheduleCreateUpdate",
    "PayScheduleCreateUpdateTypedDict",
    "PayScheduleFrequency",
    "PayScheduleFrequencyCreateUpdate",
    "PayScheduleType",
    "PayScheduleTypedDict",
    "PaymentConfigs",
    "PaymentConfigsTypedDict",
    "PaymentDirection",
    "PaymentEventType",
    "PaymentMethod",
    "PaymentMethodBankAccount",
    "PaymentMethodBankAccountTypedDict",
    "PaymentPeriod",
    "PaymentSpeedParam",
    "PaymentSpeedRequiredBody",
    "PaymentSpeedRequiredBodyTypedDict",
    "PaymentStatus",
    "PaymentUUID",
    "PaymentUnit",
    "Payroll",
    "PayrollBenefits",
    "PayrollBenefitsTypedDict",
    "PayrollBlocker",
    "PayrollBlockerTypedDict",
    "PayrollBlockersError",
    "PayrollBlockersErrorData",
    "PayrollBlockersErrorMetadata",
    "PayrollBlockersErrorMetadataTypedDict",
    "PayrollCheck",
    "PayrollCheckTypedDict",
    "PayrollCompanyTaxesType",
    "PayrollCompanyTaxesTypeTypedDict",
    "PayrollCreditBlockersType",
    "PayrollCreditBlockersTypeMetadata",
    "PayrollCreditBlockersTypeMetadataTypedDict",
    "PayrollCreditBlockersTypeStatus",
    "PayrollCreditBlockersTypeTypedDict",
    "PayrollCreditBlockersTypeUnblockOptions",
    "PayrollCreditBlockersTypeUnblockOptionsTypedDict",
    "PayrollEmployeeCompensationsType",
    "PayrollEmployeeCompensationsTypePaidTimeOff",
    "PayrollEmployeeCompensationsTypePaidTimeOffTypedDict",
    "PayrollEmployeeCompensationsTypePaymentMethod",
    "PayrollEmployeeCompensationsTypeTypedDict",
    "PayrollFixedCompensationTypesType",
    "PayrollFixedCompensationTypesTypeTypedDict",
    "PayrollMinimal",
    "PayrollMinimalTypedDict",
    "PayrollPayPeriodType",
    "PayrollPayPeriodTypeTypedDict",
    "PayrollPaymentSpeedChangedType",
    "PayrollPaymentSpeedChangedTypeTypedDict",
    "PayrollPayrollStatusMetaType",
    "PayrollPayrollStatusMetaTypeTypedDict",
    "PayrollPrepared",
    "PayrollPreparedTypedDict",
    "PayrollProcessingRequest",
    "PayrollProcessingRequestStatus",
    "PayrollProcessingRequestTypedDict",
    "PayrollReceipt",
    "PayrollReceiptTaxes",
    "PayrollReceiptTaxesTypedDict",
    "PayrollReceiptTypedDict",
    "PayrollReversal",
    "PayrollReversalTypedDict",
    "PayrollSubmissionBlockersType",
    "PayrollSubmissionBlockersTypeMetadata",
    "PayrollSubmissionBlockersTypeMetadataTypedDict",
    "PayrollSubmissionBlockersTypeStatus",
    "PayrollSubmissionBlockersTypeTypedDict",
    "PayrollTotalsType",
    "PayrollTotalsTypeTypedDict",
    "PayrollType",
    "PayrollTypedDict",
    "PayrollTypes",
    "PayrollWithholdingPayPeriodType",
    "PlaidStatus",
    "PolicyType",
    "PossibleLiabilities",
    "PossibleLiabilitiesTypedDict",
    "PostCompaniesCompanyUUIDHolidayPayPolicyColumbusDay",
    "PostCompaniesCompanyUUIDHolidayPayPolicyColumbusDayTypedDict",
    "PostCompaniesCompanyUUIDHolidayPayPolicyFederalHolidays",
    "PostCompaniesCompanyUUIDHolidayPayPolicyFederalHolidaysTypedDict",
    "PostCompaniesCompanyUUIDHolidayPayPolicyIndependenceDay",
    "PostCompaniesCompanyUUIDHolidayPayPolicyIndependenceDayTypedDict",
    "PostCompaniesCompanyUUIDHolidayPayPolicyJuneteenth",
    "PostCompaniesCompanyUUIDHolidayPayPolicyJuneteenthTypedDict",
    "PostCompaniesCompanyUUIDHolidayPayPolicyLaborDay",
    "PostCompaniesCompanyUUIDHolidayPayPolicyLaborDayTypedDict",
    "PostCompaniesCompanyUUIDHolidayPayPolicyMemorialDay",
    "PostCompaniesCompanyUUIDHolidayPayPolicyMemorialDayTypedDict",
    "PostCompaniesCompanyUUIDHolidayPayPolicyMlkDay",
    "PostCompaniesCompanyUUIDHolidayPayPolicyMlkDayTypedDict",
    "PostCompaniesCompanyUUIDHolidayPayPolicyNewYearsDay",
    "PostCompaniesCompanyUUIDHolidayPayPolicyNewYearsDayTypedDict",
    "PostCompaniesCompanyUUIDHolidayPayPolicyPresidentsDay",
    "PostCompaniesCompanyUUIDHolidayPayPolicyPresidentsDayTypedDict",
    "PostCompaniesCompanyUUIDHolidayPayPolicyRequest",
    "PostCompaniesCompanyUUIDHolidayPayPolicyRequestBody",
    "PostCompaniesCompanyUUIDHolidayPayPolicyRequestBodyTypedDict",
    "PostCompaniesCompanyUUIDHolidayPayPolicyRequestTypedDict",
    "PostCompaniesCompanyUUIDHolidayPayPolicyThanksgiving",
    "PostCompaniesCompanyUUIDHolidayPayPolicyThanksgivingTypedDict",
    "PostCompaniesCompanyUUIDHolidayPayPolicyVeteransDay",
    "PostCompaniesCompanyUUIDHolidayPayPolicyVeteransDayTypedDict",
    "PostCompaniesCompanyUUIDReportsEmploymentStatus",
    "PostCompaniesCompanyUUIDReportsPaymentMethod",
    "PostCompaniesCompanyUUIDReportsRequest",
    "PostCompaniesCompanyUUIDReportsRequestBody",
    "PostCompaniesCompanyUUIDReportsRequestBodyTypedDict",
    "PostCompaniesCompanyUUIDReportsRequestTypedDict",
    "PostCompaniesCompanyUUIDTimeOffPoliciesAccrualMethod",
    "PostCompaniesCompanyUUIDTimeOffPoliciesRequest",
    "PostCompaniesCompanyUUIDTimeOffPoliciesRequestBody",
    "PostCompaniesCompanyUUIDTimeOffPoliciesRequestBodyTypedDict",
    "PostCompaniesCompanyUUIDTimeOffPoliciesRequestTypedDict",
    "PostCompaniesPayrollSkipCompanyUUIDPayrollType",
    "PostCompaniesPayrollSkipCompanyUUIDRequest",
    "PostCompaniesPayrollSkipCompanyUUIDRequestBody",
    "PostCompaniesPayrollSkipCompanyUUIDRequestBodyTypedDict",
    "PostCompaniesPayrollSkipCompanyUUIDRequestTypedDict",
    "PostCompaniesPayrollSkipCompanyUUIDResponseBody",
    "PostCompaniesPayrollSkipCompanyUUIDResponseBodyUnion",
    "PostDepartmentsRequest",
    "PostDepartmentsRequestBody",
    "PostDepartmentsRequestBodyTypedDict",
    "PostDepartmentsRequestTypedDict",
    "PostEmployeeYtdBenefitAmountsFromDifferentCompany",
    "PostEmployeeYtdBenefitAmountsFromDifferentCompanyRequest",
    "PostEmployeeYtdBenefitAmountsFromDifferentCompanyRequestTypedDict",
    "PostEmployeeYtdBenefitAmountsFromDifferentCompanyTypedDict",
    "PostPartnerManagedCompaniesCompanyUUIDAcceptTermsOfServiceRequest",
    "PostPartnerManagedCompaniesCompanyUUIDAcceptTermsOfServiceRequestBody",
    "PostPartnerManagedCompaniesCompanyUUIDAcceptTermsOfServiceRequestBodyTypedDict",
    "PostPartnerManagedCompaniesCompanyUUIDAcceptTermsOfServiceRequestTypedDict",
    "PostPartnerManagedCompaniesCompanyUUIDAcceptTermsOfServiceResponseBody",
    "PostPartnerManagedCompaniesCompanyUUIDAcceptTermsOfServiceResponseBodyTypedDict",
    "PostPartnerManagedCompaniesCompanyUUIDRetrieveTermsOfServiceRequest",
    "PostPartnerManagedCompaniesCompanyUUIDRetrieveTermsOfServiceRequestBody",
    "PostPartnerManagedCompaniesCompanyUUIDRetrieveTermsOfServiceRequestBodyTypedDict",
    "PostPartnerManagedCompaniesCompanyUUIDRetrieveTermsOfServiceRequestTypedDict",
    "PostPartnerManagedCompaniesCompanyUUIDRetrieveTermsOfServiceResponseBody",
    "PostPartnerManagedCompaniesCompanyUUIDRetrieveTermsOfServiceResponseBodyTypedDict",
    "PostPayrollsGrossUpPayrollUUIDRequest",
    "PostPayrollsGrossUpPayrollUUIDRequestBody",
    "PostPayrollsGrossUpPayrollUUIDRequestBodyTypedDict",
    "PostPayrollsGrossUpPayrollUUIDRequestTypedDict",
    "PostPayrollsGrossUpPayrollUUIDResponseBody",
    "PostPayrollsGrossUpPayrollUUIDResponseBodyUnion",
    "PostV1CompaniesAttachmentCategory",
    "PostV1CompaniesAttachmentDocument",
    "PostV1CompaniesAttachmentDocumentTypedDict",
    "PostV1CompaniesAttachmentRequest",
    "PostV1CompaniesAttachmentRequestBody",
    "PostV1CompaniesAttachmentRequestBodyTypedDict",
    "PostV1CompaniesAttachmentRequestTypedDict",
    "PostV1CompaniesCompanyIDAdminsRequest",
    "PostV1CompaniesCompanyIDAdminsRequestBody",
    "PostV1CompaniesCompanyIDAdminsRequestBodyTypedDict",
    "PostV1CompaniesCompanyIDAdminsRequestTypedDict",
    "PostV1CompaniesCompanyIDBankAccountsAccountType",
    "PostV1CompaniesCompanyIDBankAccountsRequest",
    "PostV1CompaniesCompanyIDBankAccountsRequestBody",
    "PostV1CompaniesCompanyIDBankAccountsRequestBodyTypedDict",
    "PostV1CompaniesCompanyIDBankAccountsRequestTypedDict",
    "PostV1CompaniesCompanyIDCompanyBenefitsRequest",
    "PostV1CompaniesCompanyIDCompanyBenefitsRequestBody",
    "PostV1CompaniesCompanyIDCompanyBenefitsRequestBodyTypedDict",
    "PostV1CompaniesCompanyIDCompanyBenefitsRequestTypedDict",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsContractorPayments",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsContractorPaymentsTypedDict",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsPaymentMethod",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewContractorPayments",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewContractorPaymentsTypedDict",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewPaymentMethod",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewRequest",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewRequestBody",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewRequestBodyTypedDict",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewRequestTypedDict",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsRequest",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsRequestBody",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsRequestBodyTypedDict",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsRequestTypedDict",
    "PostV1CompaniesCompanyIDContractorPaymentsPaymentMethod",
    "PostV1CompaniesCompanyIDContractorPaymentsRequest",
    "PostV1CompaniesCompanyIDContractorPaymentsRequestBody",
    "PostV1CompaniesCompanyIDContractorPaymentsRequestBodyTypedDict",
    "PostV1CompaniesCompanyIDContractorPaymentsRequestTypedDict",
    "PostV1CompaniesCompanyIDEarningTypesRequest",
    "PostV1CompaniesCompanyIDEarningTypesRequestBody",
    "PostV1CompaniesCompanyIDEarningTypesRequestBodyTypedDict",
    "PostV1CompaniesCompanyIDEarningTypesRequestTypedDict",
    "PostV1CompaniesCompanyIDLocationsRequest",
    "PostV1CompaniesCompanyIDLocationsRequestBody",
    "PostV1CompaniesCompanyIDLocationsRequestBodyTypedDict",
    "PostV1CompaniesCompanyIDLocationsRequestTypedDict",
    "PostV1CompaniesCompanyIDPaySchedulesAssignRequest",
    "PostV1CompaniesCompanyIDPaySchedulesAssignRequestTypedDict",
    "PostV1CompaniesCompanyIDPaySchedulesAssignmentPreviewRequest",
    "PostV1CompaniesCompanyIDPaySchedulesAssignmentPreviewRequestTypedDict",
    "PostV1CompaniesCompanyIDPaySchedulesRequest",
    "PostV1CompaniesCompanyIDPaySchedulesRequestBody",
    "PostV1CompaniesCompanyIDPaySchedulesRequestBodyTypedDict",
    "PostV1CompaniesCompanyIDPaySchedulesRequestTypedDict",
    "PostV1CompaniesCompanyIDPayrollsRequest",
    "PostV1CompaniesCompanyIDPayrollsRequestBody",
    "PostV1CompaniesCompanyIDPayrollsRequestBodyTypedDict",
    "PostV1CompaniesCompanyIDPayrollsRequestTypedDict",
    "PostV1CompaniesCompanyUUIDContractorsRequest",
    "PostV1CompaniesCompanyUUIDContractorsRequestBody",
    "PostV1CompaniesCompanyUUIDContractorsRequestBodyTypedDict",
    "PostV1CompaniesCompanyUUIDContractorsRequestTypedDict",
    "PostV1CompaniesCompanyUUIDContractorsType",
    "PostV1CompaniesCompanyUUIDContractorsWageType",
    "PostV1CompaniesCompanyUUIDSignatoriesInviteRequest",
    "PostV1CompaniesCompanyUUIDSignatoriesInviteRequestBody",
    "PostV1CompaniesCompanyUUIDSignatoriesInviteRequestBodyTypedDict",
    "PostV1CompaniesCompanyUUIDSignatoriesInviteRequestTypedDict",
    "PostV1CompanyFlowsEntityType",
    "PostV1CompanyFlowsRequest",
    "PostV1CompanyFlowsRequestBody",
    "PostV1CompanyFlowsRequestBodyTypedDict",
    "PostV1CompanyFlowsRequestTypedDict",
    "PostV1CompanySignatoriesHomeAddress",
    "PostV1CompanySignatoriesHomeAddressTypedDict",
    "PostV1CompanySignatoriesRequest",
    "PostV1CompanySignatoriesRequestBody",
    "PostV1CompanySignatoriesRequestBodyTypedDict",
    "PostV1CompanySignatoriesRequestTypedDict",
    "PostV1CompensationsCompensationIDMinimumWages",
    "PostV1CompensationsCompensationIDMinimumWagesTypedDict",
    "PostV1CompensationsCompensationIDPaymentUnit",
    "PostV1CompensationsCompensationIDRequest",
    "PostV1CompensationsCompensationIDRequestBody",
    "PostV1CompensationsCompensationIDRequestBodyTypedDict",
    "PostV1CompensationsCompensationIDRequestTypedDict",
    "PostV1ContractorsContractorUUIDBankAccountsAccountType",
    "PostV1ContractorsContractorUUIDBankAccountsRequest",
    "PostV1ContractorsContractorUUIDBankAccountsRequestBody",
    "PostV1ContractorsContractorUUIDBankAccountsRequestBodyTypedDict",
    "PostV1ContractorsContractorUUIDBankAccountsRequestTypedDict",
    "PostV1EmployeesEmployeeIDBankAccountsAccountType",
    "PostV1EmployeesEmployeeIDBankAccountsRequest",
    "PostV1EmployeesEmployeeIDBankAccountsRequestBody",
    "PostV1EmployeesEmployeeIDBankAccountsRequestBodyTypedDict",
    "PostV1EmployeesEmployeeIDBankAccountsRequestTypedDict",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsContribution",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsContributionTypedDict",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsDeductionReducesTaxableIncome",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsLimitOption",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsRequest",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsRequestBody",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsRequestBodyTypedDict",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsRequestTypedDict",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsType",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsValue",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsValue2",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsValue2TypedDict",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsValueTypedDict",
    "PostV1EmployeesEmployeeIDGarnishmentsGarnishmentType",
    "PostV1EmployeesEmployeeIDGarnishmentsRequest",
    "PostV1EmployeesEmployeeIDGarnishmentsRequestBody",
    "PostV1EmployeesEmployeeIDGarnishmentsRequestBodyTypedDict",
    "PostV1EmployeesEmployeeIDGarnishmentsRequestTypedDict",
    "PostV1EmployeesEmployeeIDHomeAddressesRequest",
    "PostV1EmployeesEmployeeIDHomeAddressesRequestBody",
    "PostV1EmployeesEmployeeIDHomeAddressesRequestBodyTypedDict",
    "PostV1EmployeesEmployeeIDHomeAddressesRequestTypedDict",
    "PostV1EmployeesEmployeeIDRehireRequest",
    "PostV1EmployeesEmployeeIDRehireRequestTypedDict",
    "PostV1EmployeesEmployeeIDTerminationsRequest",
    "PostV1EmployeesEmployeeIDTerminationsRequestBody",
    "PostV1EmployeesEmployeeIDTerminationsRequestBodyTypedDict",
    "PostV1EmployeesEmployeeIDTerminationsRequestTypedDict",
    "PostV1EmployeesEmployeeIDWorkAddressesRequest",
    "PostV1EmployeesEmployeeIDWorkAddressesRequestBody",
    "PostV1EmployeesEmployeeIDWorkAddressesRequestBodyTypedDict",
    "PostV1EmployeesEmployeeIDWorkAddressesRequestTypedDict",
    "PostV1EmployeesRequest",
    "PostV1EmployeesRequestBody",
    "PostV1EmployeesRequestBodyTypedDict",
    "PostV1EmployeesRequestTypedDict",
    "PostV1ExternalPayrollRequest",
    "PostV1ExternalPayrollRequestBody",
    "PostV1ExternalPayrollRequestBodyTypedDict",
    "PostV1ExternalPayrollRequestTypedDict",
    "PostV1HistoricalEmployeesRequest",
    "PostV1HistoricalEmployeesRequestTypedDict",
    "PostV1JobsJobIDRequest",
    "PostV1JobsJobIDRequestBody",
    "PostV1JobsJobIDRequestBodyTypedDict",
    "PostV1JobsJobIDRequestTypedDict",
    "PostV1PartnerManagedCompaniesCompany",
    "PostV1PartnerManagedCompaniesCompanyTypedDict",
    "PostV1PartnerManagedCompaniesRequest",
    "PostV1PartnerManagedCompaniesRequestBody",
    "PostV1PartnerManagedCompaniesRequestBodyTypedDict",
    "PostV1PartnerManagedCompaniesRequestTypedDict",
    "PostV1PartnerManagedCompaniesResponseBody",
    "PostV1PartnerManagedCompaniesResponseBodyTypedDict",
    "PostV1PartnerManagedCompaniesSecurity",
    "PostV1PartnerManagedCompaniesSecurityTypedDict",
    "PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequest",
    "PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestBody",
    "PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestBodyTypedDict",
    "PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestTypedDict",
    "PostV1PayrollsPayrollUUIDGeneratedDocumentsPrintablePayrollChecksRequest",
    "PostV1PayrollsPayrollUUIDGeneratedDocumentsPrintablePayrollChecksRequestBody",
    "PostV1PayrollsPayrollUUIDGeneratedDocumentsPrintablePayrollChecksRequestBodyTypedDict",
    "PostV1PayrollsPayrollUUIDGeneratedDocumentsPrintablePayrollChecksRequestTypedDict",
    "PostV1PlaidProcessorTokenRequest",
    "PostV1PlaidProcessorTokenRequestBody",
    "PostV1PlaidProcessorTokenRequestBodyTypedDict",
    "PostV1PlaidProcessorTokenRequestTypedDict",
    "PostV1PlaidProcessorTokenResponseBody",
    "PostV1PlaidProcessorTokenResponseBodyTypedDict",
    "PostV1SandboxGenerate1099Request",
    "PostV1SandboxGenerate1099RequestBody",
    "PostV1SandboxGenerate1099RequestBodyTypedDict",
    "PostV1SandboxGenerate1099RequestTypedDict",
    "PostV1SandboxGenerateW2Form",
    "PostV1SandboxGenerateW2FormTypedDict",
    "PostV1SandboxGenerateW2Request",
    "PostV1SandboxGenerateW2RequestBody",
    "PostV1SandboxGenerateW2RequestBodyTypedDict",
    "PostV1SandboxGenerateW2RequestTypedDict",
    "PostV1WebhookSubscriptionRequest",
    "PostV1WebhookSubscriptionRequestBody",
    "PostV1WebhookSubscriptionRequestBodyTypedDict",
    "PostV1WebhookSubscriptionRequestTypedDict",
    "PostV1WebhookSubscriptionSecurity",
    "PostV1WebhookSubscriptionSecurityTypedDict",
    "PostV1WebhookSubscriptionSubscriptionTypes",
    "PresidentsDay",
    "PresidentsDayTypedDict",
    "PrimaryPayrollAdmin",
    "PrimaryPayrollAdminTypedDict",
    "PrimarySignatory",
    "PrimarySignatoryTypedDict",
    "PrintingFormat",
    "ProcessingStatuses",
    "PutAPIV1CompaniesCompanyIDPayrollsPayrollIDCancelRequest",
    "PutAPIV1CompaniesCompanyIDPayrollsPayrollIDCancelRequestTypedDict",
    "PutAddPeopleToDepartmentContractors",
    "PutAddPeopleToDepartmentContractorsTypedDict",
    "PutAddPeopleToDepartmentEmployees",
    "PutAddPeopleToDepartmentEmployeesTypedDict",
    "PutAddPeopleToDepartmentRequest",
    "PutAddPeopleToDepartmentRequestBody",
    "PutAddPeopleToDepartmentRequestBodyTypedDict",
    "PutAddPeopleToDepartmentRequestTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyAddEmployees",
    "PutCompaniesCompanyUUIDHolidayPayPolicyAddEmployeesTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyAddRequest",
    "PutCompaniesCompanyUUIDHolidayPayPolicyAddRequestBody",
    "PutCompaniesCompanyUUIDHolidayPayPolicyAddRequestBodyTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyAddRequestTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyChristmasDay",
    "PutCompaniesCompanyUUIDHolidayPayPolicyChristmasDayTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyColumbusDay",
    "PutCompaniesCompanyUUIDHolidayPayPolicyColumbusDayTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyFederalHolidays",
    "PutCompaniesCompanyUUIDHolidayPayPolicyFederalHolidaysTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyIndependenceDay",
    "PutCompaniesCompanyUUIDHolidayPayPolicyIndependenceDayTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyJuneteenth",
    "PutCompaniesCompanyUUIDHolidayPayPolicyJuneteenthTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyLaborDay",
    "PutCompaniesCompanyUUIDHolidayPayPolicyLaborDayTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyMemorialDay",
    "PutCompaniesCompanyUUIDHolidayPayPolicyMemorialDayTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyMlkDay",
    "PutCompaniesCompanyUUIDHolidayPayPolicyMlkDayTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyNewYearsDay",
    "PutCompaniesCompanyUUIDHolidayPayPolicyNewYearsDayTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyPresidentsDay",
    "PutCompaniesCompanyUUIDHolidayPayPolicyPresidentsDayTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyRemoveEmployees",
    "PutCompaniesCompanyUUIDHolidayPayPolicyRemoveEmployeesTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyRemoveRequest",
    "PutCompaniesCompanyUUIDHolidayPayPolicyRemoveRequestBody",
    "PutCompaniesCompanyUUIDHolidayPayPolicyRemoveRequestBodyTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyRemoveRequestTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyRequest",
    "PutCompaniesCompanyUUIDHolidayPayPolicyRequestBody",
    "PutCompaniesCompanyUUIDHolidayPayPolicyRequestBodyTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyRequestTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyThanksgiving",
    "PutCompaniesCompanyUUIDHolidayPayPolicyThanksgivingTypedDict",
    "PutCompaniesCompanyUUIDHolidayPayPolicyVeteransDay",
    "PutCompaniesCompanyUUIDHolidayPayPolicyVeteransDayTypedDict",
    "PutDepartmentsRequest",
    "PutDepartmentsRequestBody",
    "PutDepartmentsRequestBodyTypedDict",
    "PutDepartmentsRequestTypedDict",
    "PutRemovePeopleFromDepartmentContractors",
    "PutRemovePeopleFromDepartmentContractorsTypedDict",
    "PutRemovePeopleFromDepartmentEmployees",
    "PutRemovePeopleFromDepartmentEmployeesTypedDict",
    "PutRemovePeopleFromDepartmentRequest",
    "PutRemovePeopleFromDepartmentRequestBody",
    "PutRemovePeopleFromDepartmentRequestBodyTypedDict",
    "PutRemovePeopleFromDepartmentRequestTypedDict",
    "PutTimeOffPoliciesTimeOffPolicyUUIDRequest",
    "PutTimeOffPoliciesTimeOffPolicyUUIDRequestBody",
    "PutTimeOffPoliciesTimeOffPolicyUUIDRequestBodyTypedDict",
    "PutTimeOffPoliciesTimeOffPolicyUUIDRequestTypedDict",
    "PutV1CompaniesCompanyIDBankAccountsVerifyRequest",
    "PutV1CompaniesCompanyIDBankAccountsVerifyRequestBody",
    "PutV1CompaniesCompanyIDBankAccountsVerifyRequestBodyTypedDict",
    "PutV1CompaniesCompanyIDBankAccountsVerifyRequestTypedDict",
    "PutV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequest",
    "PutV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequestBody",
    "PutV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequestBodyTypedDict",
    "PutV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequestTypedDict",
    "PutV1CompaniesCompanyIDFederalTaxDetailsRequest",
    "PutV1CompaniesCompanyIDFederalTaxDetailsRequestBody",
    "PutV1CompaniesCompanyIDFederalTaxDetailsRequestBodyTypedDict",
    "PutV1CompaniesCompanyIDFederalTaxDetailsRequestTypedDict",
    "PutV1CompaniesCompanyIDPaySchedulesPayScheduleIDFrequency",
    "PutV1CompaniesCompanyIDPaySchedulesPayScheduleIDRequest",
    "PutV1CompaniesCompanyIDPaySchedulesPayScheduleIDRequestBody",
    "PutV1CompaniesCompanyIDPaySchedulesPayScheduleIDRequestBodyTypedDict",
    "PutV1CompaniesCompanyIDPaySchedulesPayScheduleIDRequestTypedDict",
    "PutV1CompaniesCompanyIDPayrollsEmployeeCompensations",
    "PutV1CompaniesCompanyIDPayrollsEmployeeCompensationsTypedDict",
    "PutV1CompaniesCompanyIDPayrollsFixedCompensations",
    "PutV1CompaniesCompanyIDPayrollsFixedCompensationsTypedDict",
    "PutV1CompaniesCompanyIDPayrollsHourlyCompensations",
    "PutV1CompaniesCompanyIDPayrollsHourlyCompensationsTypedDict",
    "PutV1CompaniesCompanyIDPayrollsPaidTimeOff",
    "PutV1CompaniesCompanyIDPayrollsPaidTimeOffTypedDict",
    "PutV1CompaniesCompanyIDPayrollsPaymentMethod",
    "PutV1CompaniesCompanyIDPayrollsPayrollIDCalculateRequest",
    "PutV1CompaniesCompanyIDPayrollsPayrollIDCalculateRequestTypedDict",
    "PutV1CompaniesCompanyIDPayrollsPayrollIDCalculateResponseBody",
    "PutV1CompaniesCompanyIDPayrollsPayrollIDCalculateResponseBodyUnion",
    "PutV1CompaniesCompanyIDPayrollsPayrollIDPrepareRequest",
    "PutV1CompaniesCompanyIDPayrollsPayrollIDPrepareRequestTypedDict",
    "PutV1CompaniesCompanyIDPayrollsPayrollIDSubmitRequest",
    "PutV1CompaniesCompanyIDPayrollsPayrollIDSubmitRequestBody",
    "PutV1CompaniesCompanyIDPayrollsPayrollIDSubmitRequestBodyTypedDict",
    "PutV1CompaniesCompanyIDPayrollsPayrollIDSubmitRequestTypedDict",
    "PutV1CompaniesCompanyIDPayrollsPayrollIDSubmitResponseBody",
    "PutV1CompaniesCompanyIDPayrollsPayrollIDSubmitResponseBodyUnion",
    "PutV1CompaniesCompanyIDPayrollsRequest",
    "PutV1CompaniesCompanyIDPayrollsRequestBody",
    "PutV1CompaniesCompanyIDPayrollsRequestBodyTypedDict",
    "PutV1CompaniesCompanyIDPayrollsRequestTypedDict",
    "PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDHomeAddress",
    "PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDHomeAddressTypedDict",
    "PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDRequest",
    "PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDRequestBody",
    "PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDRequestBodyTypedDict",
    "PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDRequestTypedDict",
    "PutV1CompaniesCompanyUUIDTaxRequirementsStateRequest",
    "PutV1CompaniesCompanyUUIDTaxRequirementsStateRequestBody",
    "PutV1CompaniesCompanyUUIDTaxRequirementsStateRequestBodyTypedDict",
    "PutV1CompaniesCompanyUUIDTaxRequirementsStateRequestTypedDict",
    "PutV1CompaniesCompanyUUIDTaxRequirementsStateRequirements",
    "PutV1CompaniesCompanyUUIDTaxRequirementsStateRequirementsTypedDict",
    "PutV1CompaniesRequest",
    "PutV1CompaniesRequestBody",
    "PutV1CompaniesRequestBodyTypedDict",
    "PutV1CompaniesRequestTypedDict",
    "PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequest",
    "PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestBody",
    "PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestBodyTypedDict",
    "PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestTypedDict",
    "PutV1CompanyBenefitsCompanyBenefitIDRequest",
    "PutV1CompanyBenefitsCompanyBenefitIDRequestBody",
    "PutV1CompanyBenefitsCompanyBenefitIDRequestBodyTypedDict",
    "PutV1CompanyBenefitsCompanyBenefitIDRequestTypedDict",
    "PutV1CompanyFormSignRequest",
    "PutV1CompanyFormSignRequestBody",
    "PutV1CompanyFormSignRequestBodyTypedDict",
    "PutV1CompanyFormSignRequestTypedDict",
    "PutV1CompanyIndustryRequest",
    "PutV1CompanyIndustryRequestBody",
    "PutV1CompanyIndustryRequestBodyTypedDict",
    "PutV1CompanyIndustryRequestTypedDict",
    "PutV1CompanyPaymentConfigsRequest",
    "PutV1CompanyPaymentConfigsRequestBody",
    "PutV1CompanyPaymentConfigsRequestBodyTypedDict",
    "PutV1CompanyPaymentConfigsRequestTypedDict",
    "PutV1CompensationsCompensationIDMinimumWages",
    "PutV1CompensationsCompensationIDMinimumWagesTypedDict",
    "PutV1CompensationsCompensationIDPaymentUnit",
    "PutV1CompensationsCompensationIDRequest",
    "PutV1CompensationsCompensationIDRequestBody",
    "PutV1CompensationsCompensationIDRequestBodyTypedDict",
    "PutV1CompensationsCompensationIDRequestTypedDict",
    "PutV1ContractorDocumentSignFields",
    "PutV1ContractorDocumentSignFieldsTypedDict",
    "PutV1ContractorDocumentSignRequest",
    "PutV1ContractorDocumentSignRequestBody",
    "PutV1ContractorDocumentSignRequestBodyTypedDict",
    "PutV1ContractorDocumentSignRequestTypedDict",
    "PutV1ContractorPaymentGroupsContractorPaymentGroupIDFundRequest",
    "PutV1ContractorPaymentGroupsContractorPaymentGroupIDFundRequestTypedDict",
    "PutV1ContractorsContractorIDPaymentMethodRequest",
    "PutV1ContractorsContractorIDPaymentMethodRequestBody",
    "PutV1ContractorsContractorIDPaymentMethodRequestBodyTypedDict",
    "PutV1ContractorsContractorIDPaymentMethodRequestTypedDict",
    "PutV1ContractorsContractorIDPaymentMethodType",
    "PutV1ContractorsContractorUUIDAddressRequest",
    "PutV1ContractorsContractorUUIDAddressRequestBody",
    "PutV1ContractorsContractorUUIDAddressRequestBodyTypedDict",
    "PutV1ContractorsContractorUUIDAddressRequestTypedDict",
    "PutV1ContractorsContractorUUIDOnboardingStatusOnboardingStatus",
    "PutV1ContractorsContractorUUIDOnboardingStatusRequest",
    "PutV1ContractorsContractorUUIDOnboardingStatusRequestBody",
    "PutV1ContractorsContractorUUIDOnboardingStatusRequestBodyTypedDict",
    "PutV1ContractorsContractorUUIDOnboardingStatusRequestTypedDict",
    "PutV1ContractorsContractorUUIDRequest",
    "PutV1ContractorsContractorUUIDRequestBody",
    "PutV1ContractorsContractorUUIDRequestBodyTypedDict",
    "PutV1ContractorsContractorUUIDRequestTypedDict",
    "PutV1ContractorsContractorUUIDType",
    "PutV1ContractorsContractorUUIDWageType",
    "PutV1EmployeeBenefitsEmployeeBenefitIDContribution",
    "PutV1EmployeeBenefitsEmployeeBenefitIDContributionTypedDict",
    "PutV1EmployeeBenefitsEmployeeBenefitIDDeductionReducesTaxableIncome",
    "PutV1EmployeeBenefitsEmployeeBenefitIDLimitOption",
    "PutV1EmployeeBenefitsEmployeeBenefitIDRequest",
    "PutV1EmployeeBenefitsEmployeeBenefitIDRequestBody",
    "PutV1EmployeeBenefitsEmployeeBenefitIDRequestBodyTypedDict",
    "PutV1EmployeeBenefitsEmployeeBenefitIDRequestTypedDict",
    "PutV1EmployeeBenefitsEmployeeBenefitIDType",
    "PutV1EmployeeBenefitsEmployeeBenefitIDValue",
    "PutV1EmployeeBenefitsEmployeeBenefitIDValue2",
    "PutV1EmployeeBenefitsEmployeeBenefitIDValue2TypedDict",
    "PutV1EmployeeBenefitsEmployeeBenefitIDValueTypedDict",
    "PutV1EmployeeFormSignRequest",
    "PutV1EmployeeFormSignRequestBody",
    "PutV1EmployeeFormSignRequestBodyTypedDict",
    "PutV1EmployeeFormSignRequestTypedDict",
    "PutV1EmployeesEmployeeIDBankAccountsAccountType",
    "PutV1EmployeesEmployeeIDBankAccountsRequest",
    "PutV1EmployeesEmployeeIDBankAccountsRequestBody",
    "PutV1EmployeesEmployeeIDBankAccountsRequestBodyTypedDict",
    "PutV1EmployeesEmployeeIDBankAccountsRequestTypedDict",
    "PutV1EmployeesEmployeeIDFederalTaxesRequest",
    "PutV1EmployeesEmployeeIDFederalTaxesRequestBody",
    "PutV1EmployeesEmployeeIDFederalTaxesRequestBodyTypedDict",
    "PutV1EmployeesEmployeeIDFederalTaxesRequestTypedDict",
    "PutV1EmployeesEmployeeIDI9AuthorizationAuthorizationStatus",
    "PutV1EmployeesEmployeeIDI9AuthorizationDocumentType",
    "PutV1EmployeesEmployeeIDI9AuthorizationDocumentsRequest",
    "PutV1EmployeesEmployeeIDI9AuthorizationDocumentsRequestBody",
    "PutV1EmployeesEmployeeIDI9AuthorizationDocumentsRequestBodyTypedDict",
    "PutV1EmployeesEmployeeIDI9AuthorizationDocumentsRequestTypedDict",
    "PutV1EmployeesEmployeeIDI9AuthorizationEmployerSignRequest",
    "PutV1EmployeesEmployeeIDI9AuthorizationEmployerSignRequestBody",
    "PutV1EmployeesEmployeeIDI9AuthorizationEmployerSignRequestBodyTypedDict",
    "PutV1EmployeesEmployeeIDI9AuthorizationEmployerSignRequestTypedDict",
    "PutV1EmployeesEmployeeIDI9AuthorizationRequest",
    "PutV1EmployeesEmployeeIDI9AuthorizationRequestBody",
    "PutV1EmployeesEmployeeIDI9AuthorizationRequestBodyTypedDict",
    "PutV1EmployeesEmployeeIDI9AuthorizationRequestTypedDict",
    "PutV1EmployeesEmployeeIDOnboardingDocumentsConfigRequest",
    "PutV1EmployeesEmployeeIDOnboardingDocumentsConfigRequestBody",
    "PutV1EmployeesEmployeeIDOnboardingDocumentsConfigRequestBodyTypedDict",
    "PutV1EmployeesEmployeeIDOnboardingDocumentsConfigRequestTypedDict",
    "PutV1EmployeesEmployeeIDOnboardingStatusRequest",
    "PutV1EmployeesEmployeeIDOnboardingStatusRequestBody",
    "PutV1EmployeesEmployeeIDOnboardingStatusRequestBodyTypedDict",
    "PutV1EmployeesEmployeeIDOnboardingStatusRequestTypedDict",
    "PutV1EmployeesEmployeeIDPaymentMethodRequest",
    "PutV1EmployeesEmployeeIDPaymentMethodRequestBody",
    "PutV1EmployeesEmployeeIDPaymentMethodRequestBodyTypedDict",
    "PutV1EmployeesEmployeeIDPaymentMethodRequestTypedDict",
    "PutV1EmployeesEmployeeIDPaymentMethodSplitBy",
    "PutV1EmployeesEmployeeIDPaymentMethodType",
    "PutV1EmployeesEmployeeIDRehireEmploymentStatus",
    "PutV1EmployeesEmployeeIDRehireRequest",
    "PutV1EmployeesEmployeeIDRehireRequestBody",
    "PutV1EmployeesEmployeeIDRehireRequestBodyTypedDict",
    "PutV1EmployeesEmployeeIDRehireRequestTypedDict",
    "PutV1EmployeesEmployeeIDStateTaxesRequest",
    "PutV1EmployeesEmployeeIDStateTaxesRequestBody",
    "PutV1EmployeesEmployeeIDStateTaxesRequestBodyTypedDict",
    "PutV1EmployeesEmployeeIDStateTaxesRequestTypedDict",
    "PutV1EmployeesRequest",
    "PutV1EmployeesRequestBody",
    "PutV1EmployeesRequestBodyTypedDict",
    "PutV1EmployeesRequestTypedDict",
    "PutV1ExternalPayrollBenefits",
    "PutV1ExternalPayrollBenefitsTypedDict",
    "PutV1ExternalPayrollEarningType",
    "PutV1ExternalPayrollEarnings",
    "PutV1ExternalPayrollEarningsTypedDict",
    "PutV1ExternalPayrollExternalPayrollItems",
    "PutV1ExternalPayrollExternalPayrollItemsTypedDict",
    "PutV1ExternalPayrollRequest",
    "PutV1ExternalPayrollRequestBody",
    "PutV1ExternalPayrollRequestBodyTypedDict",
    "PutV1ExternalPayrollRequestTypedDict",
    "PutV1ExternalPayrollTaxes",
    "PutV1ExternalPayrollTaxesTypedDict",
    "PutV1GarnishmentsGarnishmentIDRequest",
    "PutV1GarnishmentsGarnishmentIDRequestBody",
    "PutV1GarnishmentsGarnishmentIDRequestBodyTypedDict",
    "PutV1GarnishmentsGarnishmentIDRequestTypedDict",
    "PutV1HistoricalEmployeesEmployeeStateTaxes",
    "PutV1HistoricalEmployeesEmployeeStateTaxesTypedDict",
    "PutV1HistoricalEmployeesHomeAddress",
    "PutV1HistoricalEmployeesHomeAddressTypedDict",
    "PutV1HistoricalEmployeesJob",
    "PutV1HistoricalEmployeesJobTypedDict",
    "PutV1HistoricalEmployeesRequest",
    "PutV1HistoricalEmployeesRequestBody",
    "PutV1HistoricalEmployeesRequestBodyTypedDict",
    "PutV1HistoricalEmployeesRequestTypedDict",
    "PutV1HistoricalEmployeesTermination",
    "PutV1HistoricalEmployeesTerminationTypedDict",
    "PutV1HistoricalEmployeesWorkAddress",
    "PutV1HistoricalEmployeesWorkAddressTypedDict",
    "PutV1HomeAddressesHomeAddressUUIDRequest",
    "PutV1HomeAddressesHomeAddressUUIDRequestBody",
    "PutV1HomeAddressesHomeAddressUUIDRequestBodyTypedDict",
    "PutV1HomeAddressesHomeAddressUUIDRequestTypedDict",
    "PutV1JobsJobIDRequest",
    "PutV1JobsJobIDRequestBody",
    "PutV1JobsJobIDRequestBodyTypedDict",
    "PutV1JobsJobIDRequestTypedDict",
    "PutV1LocationsLocationIDRequest",
    "PutV1LocationsLocationIDRequestBody",
    "PutV1LocationsLocationIDRequestBodyTypedDict",
    "PutV1LocationsLocationIDRequestTypedDict",
    "PutV1PartnerManagedCompaniesCompanyUUIDMigrateRequest",
    "PutV1PartnerManagedCompaniesCompanyUUIDMigrateRequestBody",
    "PutV1PartnerManagedCompaniesCompanyUUIDMigrateRequestBodyTypedDict",
    "PutV1PartnerManagedCompaniesCompanyUUIDMigrateRequestTypedDict",
    "PutV1PartnerManagedCompaniesCompanyUUIDMigrateResponseBody",
    "PutV1PartnerManagedCompaniesCompanyUUIDMigrateResponseBodyTypedDict",
    "PutV1TaxLiabilitiesFinishRequest",
    "PutV1TaxLiabilitiesFinishRequestTypedDict",
    "PutV1TaxLiabilitiesRequest",
    "PutV1TaxLiabilitiesRequestBody",
    "PutV1TaxLiabilitiesRequestBodyTypedDict",
    "PutV1TaxLiabilitiesRequestTypedDict",
    "PutV1TerminationsEmployeeIDRequest",
    "PutV1TerminationsEmployeeIDRequestBody",
    "PutV1TerminationsEmployeeIDRequestBodyTypedDict",
    "PutV1TerminationsEmployeeIDRequestTypedDict",
    "PutV1TimeOffPoliciesTimeOffPolicyUUIDDeactivateRequest",
    "PutV1TimeOffPoliciesTimeOffPolicyUUIDDeactivateRequestTypedDict",
    "PutV1TimeOffPoliciesTimeOffPolicyUUIDRemoveEmployeesEmployees",
    "PutV1TimeOffPoliciesTimeOffPolicyUUIDRemoveEmployeesEmployeesTypedDict",
    "PutV1TimeOffPoliciesTimeOffPolicyUUIDRemoveEmployeesRequest",
    "PutV1TimeOffPoliciesTimeOffPolicyUUIDRemoveEmployeesRequestBody",
    "PutV1TimeOffPoliciesTimeOffPolicyUUIDRemoveEmployeesRequestBodyTypedDict",
    "PutV1TimeOffPoliciesTimeOffPolicyUUIDRemoveEmployeesRequestTypedDict",
    "PutV1VerifyWebhookSubscriptionUUIDRequest",
    "PutV1VerifyWebhookSubscriptionUUIDRequestBody",
    "PutV1VerifyWebhookSubscriptionUUIDRequestBodyTypedDict",
    "PutV1VerifyWebhookSubscriptionUUIDRequestTypedDict",
    "PutV1VerifyWebhookSubscriptionUUIDSecurity",
    "PutV1VerifyWebhookSubscriptionUUIDSecurityTypedDict",
    "PutV1WebhookSubscriptionUUIDRequest",
    "PutV1WebhookSubscriptionUUIDRequestBody",
    "PutV1WebhookSubscriptionUUIDRequestBodyTypedDict",
    "PutV1WebhookSubscriptionUUIDRequestTypedDict",
    "PutV1WebhookSubscriptionUUIDSecurity",
    "PutV1WebhookSubscriptionUUIDSecurityTypedDict",
    "PutV1WebhookSubscriptionUUIDSubscriptionTypes",
    "PutV1WorkAddressesWorkAddressUUIDRequest",
    "PutV1WorkAddressesWorkAddressUUIDRequestBody",
    "PutV1WorkAddressesWorkAddressUUIDRequestBodyTypedDict",
    "PutV1WorkAddressesWorkAddressUUIDRequestTypedDict",
    "PutVersionTimeOffPoliciesTimeOffPolicyUUIDAddEmployeesEmployees",
    "PutVersionTimeOffPoliciesTimeOffPolicyUUIDAddEmployeesEmployeesTypedDict",
    "PutVersionTimeOffPoliciesTimeOffPolicyUUIDAddEmployeesRequest",
    "PutVersionTimeOffPoliciesTimeOffPolicyUUIDAddEmployeesRequestBody",
    "PutVersionTimeOffPoliciesTimeOffPolicyUUIDAddEmployeesRequestBodyTypedDict",
    "PutVersionTimeOffPoliciesTimeOffPolicyUUIDAddEmployeesRequestTypedDict",
    "PutVersionTimeOffPoliciesTimeOffPolicyUUIDBalanceEmployees",
    "PutVersionTimeOffPoliciesTimeOffPolicyUUIDBalanceEmployeesTypedDict",
    "PutVersionTimeOffPoliciesTimeOffPolicyUUIDBalanceRequest",
    "PutVersionTimeOffPoliciesTimeOffPolicyUUIDBalanceRequestBody",
    "PutVersionTimeOffPoliciesTimeOffPolicyUUIDBalanceRequestBodyTypedDict",
    "PutVersionTimeOffPoliciesTimeOffPolicyUUIDBalanceRequestTypedDict",
    "PutWireInRequestsWireInRequestUUIDRequest",
    "PutWireInRequestsWireInRequestUUIDRequestBody",
    "PutWireInRequestsWireInRequestUUIDRequestBodyTypedDict",
    "PutWireInRequestsWireInRequestUUIDRequestTypedDict",
    "QueryParamFrequency",
    "QueryParamInclude",
    "Questions",
    "QuestionsTypedDict",
    "RateType",
    "RecipientType",
    "RecoveryCase",
    "RecoveryCaseStatus",
    "RecoveryCaseTypedDict",
    "RedebitRecoveryCaseRequest",
    "RedebitRecoveryCaseRequestTypedDict",
    "RefreshAccessTokenRequest",
    "RefreshAccessTokenRequestBody",
    "RefreshAccessTokenRequestBodyTypedDict",
    "RefreshAccessTokenRequestTypedDict",
    "Rehire",
    "RehireBody",
    "RehireBodyTypedDict",
    "RehireEmploymentStatus",
    "RehireTypedDict",
    "Report",
    "ReportTemplate",
    "ReportTemplateTypedDict",
    "ReportTypedDict",
    "RequiredAttributes",
    "RequiredAttributesTypedDict",
    "RequirementSets",
    "RequirementSetsTypedDict",
    "Requirements",
    "Resource",
    "ResourceOwner",
    "ResourceOwnerTypedDict",
    "ResourceType",
    "ResourceTypedDict",
    "Resources",
    "ResourcesTypedDict",
    "ResponseBody",
    "ResponseBodyTypedDict",
    "Schema",
    "SchemaTypedDict",
    "Section",
    "Security",
    "SecurityTypedDict",
    "Signatory",
    "SignatoryTypedDict",
    "SortOrder",
    "SplitBy",
    "Splits",
    "SplitsTypedDict",
    "States",
    "StatesTypedDict",
    "Status",
    "SubmissionBlockers",
    "SubmissionBlockersTypedDict",
    "SubscriptionTypes",
    "SupportedBenefit",
    "SupportedBenefitTypedDict",
    "TaxLiabilitiesSelections",
    "TaxLiabilitiesSelectionsTypedDict",
    "TaxPayerType",
    "TaxRequirement",
    "TaxRequirementMetadata",
    "TaxRequirementMetadataOptions",
    "TaxRequirementMetadataOptionsTypedDict",
    "TaxRequirementMetadataType",
    "TaxRequirementMetadataTypedDict",
    "TaxRequirementMetadataValidationType",
    "TaxRequirementMetadataValue",
    "TaxRequirementMetadataValueTypedDict",
    "TaxRequirementSet",
    "TaxRequirementSetTypedDict",
    "TaxRequirementTypedDict",
    "TaxRequirementValue",
    "TaxRequirementValueTypedDict",
    "TaxRequirementsState",
    "TaxRequirementsStateTypedDict",
    "TaxSuggestions",
    "TaxSuggestionsTypedDict",
    "Taxes",
    "TaxesTypedDict",
    "Termination",
    "TerminationTypedDict",
    "Thanksgiving",
    "ThanksgivingTypedDict",
    "Tier",
    "Tiers",
    "TiersTypedDict",
    "TimeOffActivity",
    "TimeOffActivityTypedDict",
    "TimeOffPolicy",
    "TimeOffPolicyEmployees",
    "TimeOffPolicyEmployeesTypedDict",
    "TimeOffPolicyTypedDict",
    "TimeOffType",
    "Total",
    "TotalTypedDict",
    "Totals",
    "TotalsTypedDict",
    "Two",
    "TwoTypedDict",
    "Type",
    "UnblockOptions",
    "UnblockOptionsTypedDict",
    "UnprocessableEntityErrorObject",
    "UnprocessableEntityErrorObjectData",
    "UnprocessedTerminationPayPeriod",
    "UnprocessedTerminationPayPeriodTypedDict",
    "User",
    "UserTypedDict",
    "Validation",
    "ValidationTypedDict",
    "Value",
    "Value2",
    "Value2TypedDict",
    "ValueTiers",
    "ValueTiersTypedDict",
    "ValueTypedDict",
    "VerificationStatus",
    "VerificationType",
    "VersionHeader",
    "VeteransDay",
    "VeteransDayTypedDict",
    "W4DataType",
    "WageType",
    "WebhookSubscription",
    "WebhookSubscriptionStatus",
    "WebhookSubscriptionTypedDict",
    "WireInRequest",
    "WireInRequestStatus",
    "WireInRequestTypedDict",
    "WithholdingPayPeriod",
    "WorkAddress",
    "WorkAddressTypedDict",
    "YtdBenefitAmountsFromDifferentCompany",
    "YtdBenefitAmountsFromDifferentCompanyTypedDict",
]
